#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .chemical_formula import chemical_formula
from .density_3 import density
from .thermal_conductivity_3 import thermal_conductivity
from .vaporization_model import vaporization_model
from .thermolysis_model import thermolysis_model
from .latent_heat_1 import latent_heat
from .volatile_fraction import volatile_fraction
from .heat_of_pyrolysis import heat_of_pyrolysis
from .specific_heat_3 import specific_heat
from .binary_diffusivity_1 import binary_diffusivity
from .diffusivity_reference_pressure import diffusivity_reference_pressure
from .averaging_coefficient_t import averaging_coefficient_t
from .averaging_coefficient_y import averaging_coefficient_y
from .vapor_pressure import vapor_pressure
from .molecular_weight_1 import molecular_weight
from .vaporization_temperature import vaporization_temperature
from .boiling_point import boiling_point
from .thermophoretic_co import thermophoretic_co
from .scattering_factor_1 import scattering_factor
from .emissivity_1 import emissivity
from .viscosity_2 import viscosity
from .dpm_surften_1 import dpm_surften
from .electric_conductivity_1 import electric_conductivity
from .dual_electric_conductivity_1 import dual_electric_conductivity
from .magnetic_permeability import magnetic_permeability
from .charge_density import charge_density
from .formation_entropy import formation_entropy
from .formation_enthalpy import formation_enthalpy
from .reference_temperature_1 import reference_temperature
class droplet_particle_child(Group):
    """
    'child_object_type' of droplet_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['chemical_formula', 'density', 'thermal_conductivity',
         'vaporization_model', 'thermolysis_model', 'latent_heat',
         'volatile_fraction', 'heat_of_pyrolysis', 'specific_heat',
         'binary_diffusivity', 'diffusivity_reference_pressure',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'vapor_pressure', 'molecular_weight', 'vaporization_temperature',
         'boiling_point', 'thermophoretic_co', 'scattering_factor',
         'emissivity', 'viscosity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'magnetic_permeability',
         'charge_density', 'formation_entropy', 'formation_enthalpy',
         'reference_temperature']

    chemical_formula: chemical_formula = chemical_formula
    """
    chemical_formula child of droplet_particle_child.
    """
    density: density = density
    """
    density child of droplet_particle_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of droplet_particle_child.
    """
    vaporization_model: vaporization_model = vaporization_model
    """
    vaporization_model child of droplet_particle_child.
    """
    thermolysis_model: thermolysis_model = thermolysis_model
    """
    thermolysis_model child of droplet_particle_child.
    """
    latent_heat: latent_heat = latent_heat
    """
    latent_heat child of droplet_particle_child.
    """
    volatile_fraction: volatile_fraction = volatile_fraction
    """
    volatile_fraction child of droplet_particle_child.
    """
    heat_of_pyrolysis: heat_of_pyrolysis = heat_of_pyrolysis
    """
    heat_of_pyrolysis child of droplet_particle_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of droplet_particle_child.
    """
    binary_diffusivity: binary_diffusivity = binary_diffusivity
    """
    binary_diffusivity child of droplet_particle_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure = diffusivity_reference_pressure
    """
    diffusivity_reference_pressure child of droplet_particle_child.
    """
    averaging_coefficient_t: averaging_coefficient_t = averaging_coefficient_t
    """
    averaging_coefficient_t child of droplet_particle_child.
    """
    averaging_coefficient_y: averaging_coefficient_y = averaging_coefficient_y
    """
    averaging_coefficient_y child of droplet_particle_child.
    """
    vapor_pressure: vapor_pressure = vapor_pressure
    """
    vapor_pressure child of droplet_particle_child.
    """
    molecular_weight: molecular_weight = molecular_weight
    """
    molecular_weight child of droplet_particle_child.
    """
    vaporization_temperature: vaporization_temperature = vaporization_temperature
    """
    vaporization_temperature child of droplet_particle_child.
    """
    boiling_point: boiling_point = boiling_point
    """
    boiling_point child of droplet_particle_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of droplet_particle_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of droplet_particle_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of droplet_particle_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of droplet_particle_child.
    """
    dpm_surften: dpm_surften = dpm_surften
    """
    dpm_surften child of droplet_particle_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of droplet_particle_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of droplet_particle_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of droplet_particle_child.
    """
    charge_density: charge_density = charge_density
    """
    charge_density child of droplet_particle_child.
    """
    formation_entropy: formation_entropy = formation_entropy
    """
    formation_entropy child of droplet_particle_child.
    """
    formation_enthalpy: formation_enthalpy = formation_enthalpy
    """
    formation_enthalpy child of droplet_particle_child.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of droplet_particle_child.
    """



import itertools
import threading
from typing import Callable, Optional


class StreamingService:
    """Encapsulates a Fluent streaming service."""

    def __init__(self, target, streaming_service):
        self._lock: threading.RLock = threading.RLock()
        self._streaming: bool = False
        self._target = target
        self._streaming_service = streaming_service
        self._stream_thread: Optional[threading.Thread] = None

        self._service_callback_id = itertools.count()
        self._service_callbacks: dict = {}

    @property
    def is_streaming(self):
        with self._lock:
            return self._streaming

    def register_callback(self, call_back: Callable, *args, **kwargs) -> str:
        """Register the callback.

        Parameters
        ----------
        call_back : Callable
            Callback to register.

        Returns
        -------
        str
            Registered callback ID.
        """
        with self._lock:
            callback_id = f"{next(self._service_callback_id)}"
            self._service_callbacks[callback_id] = [call_back, args, kwargs]
            return callback_id

    def unregister_callback(self, callback_id: str):
        """Unregister the callback.

        Parameters
        ----------
        callback_id : str
            ID of the registered callback.
        """
        with self._lock:
            if callback_id in self._service_callbacks:
                del self._service_callbacks[callback_id]

    def start(self) -> None:
        """Start streaming of Fluent transcript."""
        with self._lock:
            if not self.is_streaming:
                self._prepare()
                started_evt = threading.Event()
                self._stream_thread = threading.Thread(
                    target=self._target, args=(self, started_evt)
                )
                self._stream_thread.start()
                started_evt.wait()

    def stop(self) -> None:
        """Stop streaming of Fluent transcript."""
        if self.is_streaming:
            self._streaming_service.end_streaming()
            self._stream_thread.join()
            self._streaming = False
            self._stream_thread = None

    def _prepare(self):
        pass  # Currently only used by monitor services.



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .computed_heat_rejection import computed_heat_rejection
from .inlet_temperature import inlet_temperature
from .outlet_temperature import outlet_temperature
from .mass_flow_rate import mass_flow_rate
from .specific_heat_5 import specific_heat
class heat_exchange(Group):
    """
    'heat_exchange' child.
    """

    fluent_name = "heat-exchange"

    command_names = \
        ['computed_heat_rejection', 'inlet_temperature', 'outlet_temperature',
         'mass_flow_rate', 'specific_heat']

    computed_heat_rejection: computed_heat_rejection = computed_heat_rejection
    """
    computed_heat_rejection command of heat_exchange.
    """
    inlet_temperature: inlet_temperature = inlet_temperature
    """
    inlet_temperature command of heat_exchange.
    """
    outlet_temperature: outlet_temperature = outlet_temperature
    """
    outlet_temperature command of heat_exchange.
    """
    mass_flow_rate: mass_flow_rate = mass_flow_rate
    """
    mass_flow_rate command of heat_exchange.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat command of heat_exchange.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class set_offset_above_film_boiling_temperature(Real):
    """
    Set the temperature difference above the film boiling point.
    """

    fluent_name = "set-offset-above-film-boiling-temperature"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option import option
from .auto_range import auto_range
from .clip_to_range_1 import clip_to_range
class range(Group):
    """
    'range' child.
    """

    fluent_name = "range"

    child_names = \
        ['option', 'auto_range', 'clip_to_range']

    option: option = option
    """
    option child of range.
    """
    auto_range: auto_range = auto_range
    """
    auto_range child of range.
    """
    clip_to_range: clip_to_range = clip_to_range
    """
    clip_to_range child of range.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class track_single_particle_stream(Integer):
    """
    Specify the stream ID to be tracked.
    """

    fluent_name = "track-single-particle-stream?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "55ee2540e053a0c990a10efa67a88caa586d4bde7d45156177cee39df2dd3b85"
from .root import root


#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .high_order_rc import high_order_rc
from .high_order_rc_hybrid_treatment import high_order_rc_hybrid_treatment
from .force_treatment_of_unsteady_rc import force_treatment_of_unsteady_rc
from .unstructured_var_presto_scheme import unstructured_var_presto_scheme
from .new_framework_for_vof_specific_node_based_treatment import new_framework_for_vof_specific_node_based_treatment
class vof_numerics(Group):
    """
    Set VOF numeric options.
    """

    fluent_name = "vof-numerics"

    child_names = \
        ['high_order_rc', 'high_order_rc_hybrid_treatment',
         'force_treatment_of_unsteady_rc', 'unstructured_var_presto_scheme',
         'new_framework_for_vof_specific_node_based_treatment']

    high_order_rc: high_order_rc = high_order_rc
    """
    high_order_rc child of vof_numerics.
    """
    high_order_rc_hybrid_treatment: high_order_rc_hybrid_treatment = high_order_rc_hybrid_treatment
    """
    high_order_rc_hybrid_treatment child of vof_numerics.
    """
    force_treatment_of_unsteady_rc: force_treatment_of_unsteady_rc = force_treatment_of_unsteady_rc
    """
    force_treatment_of_unsteady_rc child of vof_numerics.
    """
    unstructured_var_presto_scheme: unstructured_var_presto_scheme = unstructured_var_presto_scheme
    """
    unstructured_var_presto_scheme child of vof_numerics.
    """
    new_framework_for_vof_specific_node_based_treatment: new_framework_for_vof_specific_node_based_treatment = new_framework_for_vof_specific_node_based_treatment
    """
    new_framework_for_vof_specific_node_based_treatment child of vof_numerics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enforce_laplace_coarsening import enforce_laplace_coarsening
from .increase_pre_sweeps import increase_pre_sweeps
from .pre_sweeps_3 import pre_sweeps
from .specify_coarsening_rate import specify_coarsening_rate
from .coarsen_rate import coarsen_rate
class amg(Group):
    """
    'amg' child.
    """

    fluent_name = "amg"

    child_names = \
        ['enforce_laplace_coarsening', 'increase_pre_sweeps', 'pre_sweeps',
         'specify_coarsening_rate', 'coarsen_rate']

    enforce_laplace_coarsening: enforce_laplace_coarsening = enforce_laplace_coarsening
    """
    enforce_laplace_coarsening child of amg.
    """
    increase_pre_sweeps: increase_pre_sweeps = increase_pre_sweeps
    """
    increase_pre_sweeps child of amg.
    """
    pre_sweeps: pre_sweeps = pre_sweeps
    """
    pre_sweeps child of amg.
    """
    specify_coarsening_rate: specify_coarsening_rate = specify_coarsening_rate
    """
    specify_coarsening_rate child of amg.
    """
    coarsen_rate: coarsen_rate = coarsen_rate
    """
    coarsen_rate child of amg.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .domain_val import domain_val
class species_mass_flow(Command):
    """
    'species_mass_flow' command.
    
    Parameters
    ----------
        domain_val : str
            'domain_val' child.
    
    """

    fluent_name = "species-mass-flow"

    argument_names = \
        ['domain_val']

    domain_val: domain_val = domain_val
    """
    domain_val argument of species_mass_flow.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .plane_surface_child import plane_surface_child

class plane_surface(NamedObject[plane_surface_child], _CreatableNamedObjectMixin[plane_surface_child]):
    """
    'plane_surface' child.
    """

    fluent_name = "plane-surface"

    child_object_type: plane_surface_child = plane_surface_child
    """
    child_object_type of plane_surface.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class base_face_zone_for_partitioning(IntegerList):
    """
    'base_face_zone_for_partitioning' child.
    """

    fluent_name = "base-face-zone-for-partitioning"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class aero_optical_distortions(Command):
    """
    Optics report menu.
    """

    fluent_name = "aero-optical-distortions"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .terminology import terminology
from .disk_normal_x import disk_normal_x
from .disk_normal_y import disk_normal_y
from .disk_normal_z import disk_normal_z
from .disk_pitch_angle import disk_pitch_angle
from .disk_bank_angle import disk_bank_angle
class disk_orientation(Group):
    """
    Menu to define the rotor disk orientation.
    
     - terminology      : the terminology to specify the rotor disk orientation: rotor-disk-angles / rotor-disk-normal, 
     - disk-normal-x/yz : rotor-disk-normal components, 
     - disk-pitch-angle : , 
     - disk-bank-angle : , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "disk-orientation"

    child_names = \
        ['terminology', 'disk_normal_x', 'disk_normal_y', 'disk_normal_z',
         'disk_pitch_angle', 'disk_bank_angle']

    terminology: terminology = terminology
    """
    terminology child of disk_orientation.
    """
    disk_normal_x: disk_normal_x = disk_normal_x
    """
    disk_normal_x child of disk_orientation.
    """
    disk_normal_y: disk_normal_y = disk_normal_y
    """
    disk_normal_y child of disk_orientation.
    """
    disk_normal_z: disk_normal_z = disk_normal_z
    """
    disk_normal_z child of disk_orientation.
    """
    disk_pitch_angle: disk_pitch_angle = disk_pitch_angle
    """
    disk_pitch_angle child of disk_orientation.
    """
    disk_bank_angle: disk_bank_angle = disk_bank_angle
    """
    disk_bank_angle child of disk_orientation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .model import model
from .options_2 import options
from .controls import controls
from .expert import expert
class structure(Group):
    """
    'structure' child.
    """

    fluent_name = "structure"

    child_names = \
        ['model', 'options', 'controls', 'expert']

    model: model = model
    """
    model child of structure.
    """
    options: options = options
    """
    options child of structure.
    """
    controls: controls = controls
    """
    controls child of structure.
    """
    expert: expert = expert
    """
    expert child of structure.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .auto_scale_2 import auto_scale
from .clip_to_range_2 import clip_to_range
from .surfaces_1 import surfaces
from .filled_contours import filled_contours
from .global_range_1 import global_range
from .line_contours import line_contours
from .log_scale_2 import log_scale
from .n_contour import n_contour
from .node_values_2 import node_values
from .render_mesh import render_mesh
from .coloring_2 import coloring
class contours(Group):
    """
    'contours' child.
    """

    fluent_name = "contours"

    child_names = \
        ['auto_scale', 'clip_to_range', 'surfaces', 'filled_contours',
         'global_range', 'line_contours', 'log_scale', 'n_contour',
         'node_values', 'render_mesh', 'coloring']

    auto_scale: auto_scale = auto_scale
    """
    auto_scale child of contours.
    """
    clip_to_range: clip_to_range = clip_to_range
    """
    clip_to_range child of contours.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of contours.
    """
    filled_contours: filled_contours = filled_contours
    """
    filled_contours child of contours.
    """
    global_range: global_range = global_range
    """
    global_range child of contours.
    """
    line_contours: line_contours = line_contours
    """
    line_contours child of contours.
    """
    log_scale: log_scale = log_scale
    """
    log_scale child of contours.
    """
    n_contour: n_contour = n_contour
    """
    n_contour child of contours.
    """
    node_values: node_values = node_values
    """
    node_values child of contours.
    """
    render_mesh: render_mesh = render_mesh
    """
    render_mesh child of contours.
    """
    coloring: coloring = coloring
    """
    coloring child of contours.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .poisson_ratio_01 import poisson_ratio_01
from .poisson_ratio_12 import poisson_ratio_12
from .poisson_ratio_02 import poisson_ratio_02
class orthotropic_structure_nu(Group):
    """
    'orthotropic_structure_nu' child.
    """

    fluent_name = "orthotropic-structure-nu"

    child_names = \
        ['poisson_ratio_01', 'poisson_ratio_12', 'poisson_ratio_02']

    poisson_ratio_01: poisson_ratio_01 = poisson_ratio_01
    """
    poisson_ratio_01 child of orthotropic_structure_nu.
    """
    poisson_ratio_12: poisson_ratio_12 = poisson_ratio_12
    """
    poisson_ratio_12 child of orthotropic_structure_nu.
    """
    poisson_ratio_02: poisson_ratio_02 = poisson_ratio_02
    """
    poisson_ratio_02 child of orthotropic_structure_nu.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .face_zone_id import face_zone_id
class orient_face_zone(Command):
    """
    Orient the face zone.
    
    Parameters
    ----------
        face_zone_id : int
            'face_zone_id' child.
    
    """

    fluent_name = "orient-face-zone"

    argument_names = \
        ['face_zone_id']

    face_zone_id: face_zone_id = face_zone_id
    """
    face_zone_id argument of orient_face_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .contour import contour
from .mesh_2 import mesh
from .vector import vector
from .pathline import pathline
from .particle_track import particle_track
from .lic import lic
from .olic import olic
from .contours import contours
from .particle_tracks import particle_tracks
from .colors import colors
from .lights import lights
from .picture import picture
from .views import views
from .windows import windows
class graphics(Group, _ChildNamedObjectAccessorMixin):
    """
    'graphics' child.
    """

    fluent_name = "graphics"

    child_names = \
        ['contour', 'mesh', 'vector', 'pathline', 'particle_track', 'lic',
         'olic', 'contours', 'particle_tracks', 'colors', 'lights', 'picture',
         'views', 'windows']

    contour: contour = contour
    """
    contour child of graphics.
    """
    mesh: mesh = mesh
    """
    mesh child of graphics.
    """
    vector: vector = vector
    """
    vector child of graphics.
    """
    pathline: pathline = pathline
    """
    pathline child of graphics.
    """
    particle_track: particle_track = particle_track
    """
    particle_track child of graphics.
    """
    lic: lic = lic
    """
    lic child of graphics.
    """
    olic: olic = olic
    """
    olic child of graphics.
    """
    contours: contours = contours
    """
    contours child of graphics.
    """
    particle_tracks: particle_tracks = particle_tracks
    """
    particle_tracks child of graphics.
    """
    colors: colors = colors
    """
    colors child of graphics.
    """
    lights: lights = lights
    """
    lights child of graphics.
    """
    picture: picture = picture
    """
    picture child of graphics.
    """
    views: views = views
    """
    views child of graphics.
    """
    windows: windows = windows
    """
    windows child of graphics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .anisotropic_boundary_zones import anisotropic_boundary_zones
from .cell_zones import cell_zones
from .dynamic_adaption_frequency import dynamic_adaption_frequency
from .verbosity import verbosity
from .encapsulate_children import encapsulate_children
from .maximum_refinement_level import maximum_refinement_level
from .minimum_cell_quality import minimum_cell_quality
from .maximum_cell_count import maximum_cell_count
from .additional_refinement_layers import additional_refinement_layers
from .anisotropic_adaption import anisotropic_adaption
from .minimum_edge_length import minimum_edge_length
from .anisotropic_split_ratio import anisotropic_split_ratio
from .overset_adapt_dead_cells import overset_adapt_dead_cells
from .dynamic_adaption import dynamic_adaption
class set(Group):
    """
    Enter the adaption set menu.
    """

    fluent_name = "set"

    child_names = \
        ['anisotropic_boundary_zones', 'cell_zones',
         'dynamic_adaption_frequency', 'verbosity', 'encapsulate_children',
         'maximum_refinement_level', 'minimum_cell_quality',
         'maximum_cell_count', 'additional_refinement_layers',
         'anisotropic_adaption', 'minimum_edge_length',
         'anisotropic_split_ratio', 'overset_adapt_dead_cells']

    anisotropic_boundary_zones: anisotropic_boundary_zones = anisotropic_boundary_zones
    """
    anisotropic_boundary_zones child of set.
    """
    cell_zones: cell_zones = cell_zones
    """
    cell_zones child of set.
    """
    dynamic_adaption_frequency: dynamic_adaption_frequency = dynamic_adaption_frequency
    """
    dynamic_adaption_frequency child of set.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of set.
    """
    encapsulate_children: encapsulate_children = encapsulate_children
    """
    encapsulate_children child of set.
    """
    maximum_refinement_level: maximum_refinement_level = maximum_refinement_level
    """
    maximum_refinement_level child of set.
    """
    minimum_cell_quality: minimum_cell_quality = minimum_cell_quality
    """
    minimum_cell_quality child of set.
    """
    maximum_cell_count: maximum_cell_count = maximum_cell_count
    """
    maximum_cell_count child of set.
    """
    additional_refinement_layers: additional_refinement_layers = additional_refinement_layers
    """
    additional_refinement_layers child of set.
    """
    anisotropic_adaption: anisotropic_adaption = anisotropic_adaption
    """
    anisotropic_adaption child of set.
    """
    minimum_edge_length: minimum_edge_length = minimum_edge_length
    """
    minimum_edge_length child of set.
    """
    anisotropic_split_ratio: anisotropic_split_ratio = anisotropic_split_ratio
    """
    anisotropic_split_ratio child of set.
    """
    overset_adapt_dead_cells: overset_adapt_dead_cells = overset_adapt_dead_cells
    """
    overset_adapt_dead_cells child of set.
    """
    command_names = \
        ['dynamic_adaption']

    dynamic_adaption: dynamic_adaption = dynamic_adaption
    """
    dynamic_adaption command of set.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .formulation import formulation
from .local_time_step_settings import local_time_step_settings
from .global_time_step_settings import global_time_step_settings
from .advanced_options import advanced_options
from .relaxation_factors import relaxation_factors
from .verbosity_3 import verbosity
class pseudo_time_method(Group):
    """
    'pseudo_time_method' child.
    """

    fluent_name = "pseudo-time-method"

    child_names = \
        ['formulation', 'local_time_step_settings',
         'global_time_step_settings', 'advanced_options',
         'relaxation_factors', 'verbosity']

    formulation: formulation = formulation
    """
    formulation child of pseudo_time_method.
    """
    local_time_step_settings: local_time_step_settings = local_time_step_settings
    """
    local_time_step_settings child of pseudo_time_method.
    """
    global_time_step_settings: global_time_step_settings = global_time_step_settings
    """
    global_time_step_settings child of pseudo_time_method.
    """
    advanced_options: advanced_options = advanced_options
    """
    advanced_options child of pseudo_time_method.
    """
    relaxation_factors: relaxation_factors = relaxation_factors
    """
    relaxation_factors child of pseudo_time_method.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of pseudo_time_method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .embedded_face_zone import embedded_face_zone
from .floating_surface import floating_surface
class disk_id(Group):
    """
    Menu to define the disk face/surface name:
    
     - embedded-face-zone: select embedded-face-zone name, 
     - floating-disk	: select floating-surface name, 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "disk-id"

    child_names = \
        ['embedded_face_zone', 'floating_surface']

    embedded_face_zone: embedded_face_zone = embedded_face_zone
    """
    embedded_face_zone child of disk_id.
    """
    floating_surface: floating_surface = floating_surface
    """
    floating_surface child of disk_id.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .min_diam import min_diam
from .max_diam import max_diam
from .mean_diam import mean_diam
from .spread import spread
from .number_of_diameters import number_of_diameters
class rosin_rammler_settings(Group):
    """
    'rosin_rammler_settings' child.
    """

    fluent_name = "rosin-rammler-settings"

    child_names = \
        ['min_diam', 'max_diam', 'mean_diam', 'spread', 'number_of_diameters']

    min_diam: min_diam = min_diam
    """
    min_diam child of rosin_rammler_settings.
    """
    max_diam: max_diam = max_diam
    """
    max_diam child of rosin_rammler_settings.
    """
    mean_diam: mean_diam = mean_diam
    """
    mean_diam child of rosin_rammler_settings.
    """
    spread: spread = spread
    """
    spread child of rosin_rammler_settings.
    """
    number_of_diameters: number_of_diameters = number_of_diameters
    """
    number_of_diameters child of rosin_rammler_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class bitrate_scale(String):
    """
    Mp4 bitrate scale - Best-64000 High-32000 Medium-16000 Low-8000.
    """

    fluent_name = "bitrate-scale"




from ansys.fluent.core.launcher.launcher import (
    FluentVersion,
    launch_fluent,
    set_ansys_version,
)
from ansys.fluent.core.session_solver import Solver


def setup_for_fluent(*args, **kwargs):
    """Returns global PyConsole objects."""

    if kwargs["product_version"] == "22.2.0":
        set_ansys_version(FluentVersion.version_22R2)
    elif kwargs["product_version"] == "23.1.0":
        set_ansys_version(FluentVersion.version_23R1)
    elif kwargs["product_version"] == "23.2.0":
        set_ansys_version(FluentVersion.version_23R2)

    del kwargs["product_version"]

    session = launch_fluent(*args, **kwargs)
    globals = {}
    if "mode" in kwargs.keys() and kwargs["mode"] == "meshing":
        globals["meshing"] = session.meshing
        globals["PartManagement"] = session.PartManagement
        globals["PMFileManagement"] = session.PMFileManagement
        globals["solver"] = Solver(fluent_connection=session.fluent_connection)
    elif "mode" in kwargs.keys() and kwargs["mode"] == "solver":
        globals["solver"] = session
        globals["solverworkflow"] = session.solverworkflow

    globals["preferences"] = session.preferences
    globals["workflow"] = session.workflow

    return globals



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class blade_pitch_cyclic_cos(Real):
    """
    Set magnitude of cos component of blade's cyclic pitch angle:.
    """

    fluent_name = "blade-pitch-cyclic-cos"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .piecewise_polynomial_child_1 import piecewise_polynomial_child

class piecewise_polynomial(ListObject[piecewise_polynomial_child]):
    """
    'piecewise_polynomial' child.
    """

    fluent_name = "piecewise-polynomial"

    child_object_type: piecewise_polynomial_child = piecewise_polynomial_child
    """
    child_object_type of piecewise_polynomial.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class blended_treatment_for_buoyancy_forces(Boolean):
    """
    Enable/disable use of  blended treatment for buoyancy force.
    """

    fluent_name = "blended-treatment-for-buoyancy-forces?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .fan_child import fan_child

class fan(NamedObject[fan_child], _CreatableNamedObjectMixin[fan_child]):
    """
    'fan' child.
    """

    fluent_name = "fan"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of fan.
    """
    child_object_type: fan_child = fan_child
    """
    child_object_type of fan.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .contour_plotting_option import contour_plotting_option
from .interaction import interaction
from .unsteady_tracking import unsteady_tracking
class general_settings(Group):
    """
    Main menu to allow users to set options controlling:
    
     - the optional generation of averaged dpm variables on the fluid mesh to be used for post-processing,
     - the interaction between the discrete particles and their carrier phase,
     - the handling of unsteady particles.
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "general-settings"

    child_names = \
        ['contour_plotting_option', 'interaction', 'unsteady_tracking']

    contour_plotting_option: contour_plotting_option = contour_plotting_option
    """
    contour_plotting_option child of general_settings.
    """
    interaction: interaction = interaction
    """
    interaction child of general_settings.
    """
    unsteady_tracking: unsteady_tracking = unsteady_tracking
    """
    unsteady_tracking child of general_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .markers_child import markers_child

class markers(ListObject[markers_child]):
    """
    'markers' child.
    """

    fluent_name = "markers"

    child_object_type: markers_child = markers_child
    """
    child_object_type of markers.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

"""A package providing Fluent's Settings Objects in Python."""
from ansys.fluent.core.solver.flobject import *

SHASH = "846651180021db9a3edbc5cae7381cc7bfb834ef3a32b4e8e5f0d6504ea25f57"
from .root import root


#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .sample import sample
class delete_sample(Command):
    """
    'delete_sample' command.
    
    Parameters
    ----------
        sample : str
            'sample' child.
    
    """

    fluent_name = "delete-sample"

    argument_names = \
        ['sample']

    sample: sample = sample
    """
    sample argument of delete_sample.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class disk_pitch_angle(Real):
    """
    Set disk pitch angle:.
    """

    fluent_name = "disk-pitch-angle"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_origin import axis_origin
from .axis_direction import axis_direction
from .radial_conductivity import radial_conductivity
from .tangential_conductivity import tangential_conductivity
from .axial_conductivity import axial_conductivity
class cyl_orthotropic(Group):
    """
    'cyl_orthotropic' child.
    """

    fluent_name = "cyl-orthotropic"

    child_names = \
        ['axis_origin', 'axis_direction', 'radial_conductivity',
         'tangential_conductivity', 'axial_conductivity']

    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of cyl_orthotropic.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of cyl_orthotropic.
    """
    radial_conductivity: radial_conductivity = radial_conductivity
    """
    radial_conductivity child of cyl_orthotropic.
    """
    tangential_conductivity: tangential_conductivity = tangential_conductivity
    """
    tangential_conductivity child of cyl_orthotropic.
    """
    axial_conductivity: axial_conductivity = axial_conductivity
    """
    axial_conductivity child of cyl_orthotropic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .zone_name import zone_name
from .overwrite import overwrite
class copy_mrf_to_mesh_motion(Command):
    """
    Copy motion variable values for origin, axis and velocities from Frame Motion to Mesh Motion.
    
    Parameters
    ----------
        zone_name : str
            'zone_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "copy-mrf-to-mesh-motion"

    argument_names = \
        ['zone_name', 'overwrite']

    zone_name: zone_name = zone_name
    """
    zone_name argument of copy_mrf_to_mesh_motion.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of copy_mrf_to_mesh_motion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class specific_internal_surface_area(Real):
    """
    'specific_internal_surface_area' child.
    """

    fluent_name = "specific-internal-surface-area"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class mean_and_std_deviation(RealList):
    """
    Set mean and standard deviation.
    """

    fluent_name = "mean-and-std-deviation"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .multi_stage_child import multi_stage_child

class multi_stage(ListObject[multi_stage_child]):
    """
    'multi_stage' child.
    """

    fluent_name = "multi-stage"

    child_object_type: multi_stage_child = multi_stage_child
    """
    child_object_type of multi_stage.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .orig_beam_name import orig_beam_name
from .beam_name import beam_name
from .ap_face_zone import ap_face_zone
from .beam_length import beam_length
from .ray_npoints import ray_npoints
from .x_beam_vector import x_beam_vector
from .y_beam_vector import y_beam_vector
from .z_beam_vector import z_beam_vector
class copy(Command):
    """
    Copy optical beam grid.
    
    Parameters
    ----------
        orig_beam_name : str
            Choose the name for the optical beam to be copied.
        beam_name : str
            Set a unique name for each optical beam.
        ap_face_zone : str
            Set the wall face zones to specify the optical aperture surface.
        beam_length : real
            Set the length of optical beam propagation.
        ray_npoints : int
            Set the number of grid point in each ray of the optical beam.
        x_beam_vector : real
            Set the x-component of the beam propagation vector.
        y_beam_vector : real
            Set the y-component of the beam propagation vector.
        z_beam_vector : real
            Set the z-component of the beam propagation vector.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['orig_beam_name', 'beam_name', 'ap_face_zone', 'beam_length',
         'ray_npoints', 'x_beam_vector', 'y_beam_vector', 'z_beam_vector']

    orig_beam_name: orig_beam_name = orig_beam_name
    """
    orig_beam_name argument of copy.
    """
    beam_name: beam_name = beam_name
    """
    beam_name argument of copy.
    """
    ap_face_zone: ap_face_zone = ap_face_zone
    """
    ap_face_zone argument of copy.
    """
    beam_length: beam_length = beam_length
    """
    beam_length argument of copy.
    """
    ray_npoints: ray_npoints = ray_npoints
    """
    ray_npoints argument of copy.
    """
    x_beam_vector: x_beam_vector = x_beam_vector
    """
    x_beam_vector argument of copy.
    """
    y_beam_vector: y_beam_vector = y_beam_vector
    """
    y_beam_vector argument of copy.
    """
    z_beam_vector: z_beam_vector = z_beam_vector
    """
    z_beam_vector argument of copy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .migrate_and_reorder import migrate_and_reorder
from .preserve_boundary_layer import preserve_boundary_layer
from .preserve_interior_zones import preserve_interior_zones
class options(Group):
    """
    Enter options menu.
    """

    fluent_name = "options"

    child_names = \
        ['migrate_and_reorder', 'preserve_boundary_layer',
         'preserve_interior_zones']

    migrate_and_reorder: migrate_and_reorder = migrate_and_reorder
    """
    migrate_and_reorder child of options.
    """
    preserve_boundary_layer: preserve_boundary_layer = preserve_boundary_layer
    """
    preserve_boundary_layer child of options.
    """
    preserve_interior_zones: preserve_interior_zones = preserve_interior_zones
    """
    preserve_interior_zones child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .chemical_formula import chemical_formula
from .density_5 import density
from .specific_heat_4 import specific_heat
from .species_1 import species
from .vp_equilib import vp_equilib
from .thermal_conductivity_3 import thermal_conductivity
from .viscosity_2 import viscosity
from .dpm_surften import dpm_surften
from .emissivity_2 import emissivity
from .scattering_factor_2 import scattering_factor
from .vaporization_model import vaporization_model
from .averaging_coefficient_t import averaging_coefficient_t
from .averaging_coefficient_y import averaging_coefficient_y
from .thermophoretic_co import thermophoretic_co
from .reaction_model import reaction_model
class particle_mixture_child(Group):
    """
    'child_object_type' of particle_mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['chemical_formula', 'density', 'specific_heat', 'species',
         'vp_equilib', 'thermal_conductivity', 'viscosity', 'dpm_surften',
         'emissivity', 'scattering_factor', 'vaporization_model',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'thermophoretic_co', 'reaction_model']

    chemical_formula: chemical_formula = chemical_formula
    """
    chemical_formula child of particle_mixture_child.
    """
    density: density = density
    """
    density child of particle_mixture_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of particle_mixture_child.
    """
    species: species = species
    """
    species child of particle_mixture_child.
    """
    vp_equilib: vp_equilib = vp_equilib
    """
    vp_equilib child of particle_mixture_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of particle_mixture_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of particle_mixture_child.
    """
    dpm_surften: dpm_surften = dpm_surften
    """
    dpm_surften child of particle_mixture_child.
    """
    emissivity: emissivity = emissivity
    """
    emissivity child of particle_mixture_child.
    """
    scattering_factor: scattering_factor = scattering_factor
    """
    scattering_factor child of particle_mixture_child.
    """
    vaporization_model: vaporization_model = vaporization_model
    """
    vaporization_model child of particle_mixture_child.
    """
    averaging_coefficient_t: averaging_coefficient_t = averaging_coefficient_t
    """
    averaging_coefficient_t child of particle_mixture_child.
    """
    averaging_coefficient_y: averaging_coefficient_y = averaging_coefficient_y
    """
    averaging_coefficient_y child of particle_mixture_child.
    """
    thermophoretic_co: thermophoretic_co = thermophoretic_co
    """
    thermophoretic_co child of particle_mixture_child.
    """
    reaction_model: reaction_model = reaction_model
    """
    reaction_model child of particle_mixture_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .physical_models_2 import physical_models
from .dynamic_mesh import dynamic_mesh
from .mesh_adaption import mesh_adaption
class load_balance(Group):
    """
    'load_balance' child.
    """

    fluent_name = "load-balance"

    child_names = \
        ['physical_models', 'dynamic_mesh', 'mesh_adaption']

    physical_models: physical_models = physical_models
    """
    physical_models child of load_balance.
    """
    dynamic_mesh: dynamic_mesh = dynamic_mesh
    """
    dynamic_mesh child of load_balance.
    """
    mesh_adaption: mesh_adaption = mesh_adaption
    """
    mesh_adaption child of load_balance.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class ia_norm_min_limit(Real):
    """
    Minimum normalized area density below which mass transfer rate is set to zero.
    """

    fluent_name = "ia-norm-min-limit"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mod_name import mod_name
class enable_modification(Command):
    """
    Enable a single defined case modification.
    
    Parameters
    ----------
        mod_name : str
            'mod_name' child.
    
    """

    fluent_name = "enable-modification"

    argument_names = \
        ['mod_name']

    mod_name: mod_name = mod_name
    """
    mod_name argument of enable_modification.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .copy_from import copy_from
from .copy_to import copy_to
class copy(Command):
    """
    'copy' command.
    
    Parameters
    ----------
        copy_from : str
            'copy_from' child.
        copy_to : str
            'copy_to' child.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['copy_from', 'copy_to']

    copy_from: copy_from = copy_from
    """
    copy_from argument of copy.
    """
    copy_to: copy_to = copy_to
    """
    copy_to argument of copy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .type_1 import type
from .name import name
class copy_database_material_by_name(Command):
    """
    'copy_database_material_by_name' command.
    
    Parameters
    ----------
        type : str
            'type' child.
        name : str
            'name' child.
    
    """

    fluent_name = "copy-database-material-by-name"

    argument_names = \
        ['type', 'name']

    type: type = type
    """
    type argument of copy_database_material_by_name.
    """
    name: name = name
    """
    name argument of copy_database_material_by_name.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .use import use
from .user_defined_2 import user_defined
from .value import value
from .hybrid_optimization import hybrid_optimization
class particle_weight(Group):
    """
    Set DPM particle weight.
    """

    fluent_name = "particle-weight"

    child_names = \
        ['use', 'user_defined', 'value', 'hybrid_optimization']

    use: use = use
    """
    use child of particle_weight.
    """
    user_defined: user_defined = user_defined
    """
    user_defined child of particle_weight.
    """
    value: value = value
    """
    value child of particle_weight.
    """
    hybrid_optimization: hybrid_optimization = hybrid_optimization
    """
    hybrid_optimization child of particle_weight.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class n_smooth_for_interfacial_regims(Integer):
    """
    Number of smoothings for interfacial regime.
    """

    fluent_name = "n-smooth-for-interfacial-regims"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .cone_type import cone_type
from .inject_as_film import inject_as_film
class injection_type(Group):
    """
    'injection_type' child.
    """

    fluent_name = "injection-type"

    child_names = \
        ['option', 'cone_type', 'inject_as_film']

    option: option = option
    """
    option child of injection_type.
    """
    cone_type: cone_type = cone_type
    """
    cone_type child of injection_type.
    """
    inject_as_film: inject_as_film = inject_as_film
    """
    inject_as_film child of injection_type.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .remove_limiter import remove_limiter
from .report_leidenfrost_temperature import report_leidenfrost_temperature
from .set_offset_above_film_boiling_temperature import set_offset_above_film_boiling_temperature
class wall_film_temperature_limiter(Group):
    """
    'wall_film_temperature_limiter' child.
    """

    fluent_name = "wall-film-temperature-limiter"

    child_names = \
        ['remove_limiter', 'report_leidenfrost_temperature',
         'set_offset_above_film_boiling_temperature']

    remove_limiter: remove_limiter = remove_limiter
    """
    remove_limiter child of wall_film_temperature_limiter.
    """
    report_leidenfrost_temperature: report_leidenfrost_temperature = report_leidenfrost_temperature
    """
    report_leidenfrost_temperature child of wall_film_temperature_limiter.
    """
    set_offset_above_film_boiling_temperature: set_offset_above_film_boiling_temperature = set_offset_above_film_boiling_temperature
    """
    set_offset_above_film_boiling_temperature child of wall_film_temperature_limiter.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .dispersion_force_in_momentum import dispersion_force_in_momentum
from .dispersion_in_relative_velocity import dispersion_in_relative_velocity
class multiphase_options(Group):
    """
    'multiphase_options' child.
    """

    fluent_name = "multiphase-options"

    child_names = \
        ['dispersion_force_in_momentum', 'dispersion_in_relative_velocity']

    dispersion_force_in_momentum: dispersion_force_in_momentum = dispersion_force_in_momentum
    """
    dispersion_force_in_momentum child of multiphase_options.
    """
    dispersion_in_relative_velocity: dispersion_in_relative_velocity = dispersion_in_relative_velocity
    """
    dispersion_in_relative_velocity child of multiphase_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .error_tolerance_1 import error_tolerance
from .initial_time_step_size import initial_time_step_size
from .fixed_time_step_size import fixed_time_step_size
from .min_time_step_size import min_time_step_size
from .max_time_step_size import max_time_step_size
from .min_step_change_factor import min_step_change_factor
from .max_step_change_factor import max_step_change_factor
from .update_interval import update_interval
class error_based_time_stepping(Group):
    """
    'error_based_time_stepping' child.
    """

    fluent_name = "error-based-time-stepping"

    child_names = \
        ['error_tolerance', 'initial_time_step_size', 'fixed_time_step_size',
         'min_time_step_size', 'max_time_step_size', 'min_step_change_factor',
         'max_step_change_factor', 'update_interval']

    error_tolerance: error_tolerance = error_tolerance
    """
    error_tolerance child of error_based_time_stepping.
    """
    initial_time_step_size: initial_time_step_size = initial_time_step_size
    """
    initial_time_step_size child of error_based_time_stepping.
    """
    fixed_time_step_size: fixed_time_step_size = fixed_time_step_size
    """
    fixed_time_step_size child of error_based_time_stepping.
    """
    min_time_step_size: min_time_step_size = min_time_step_size
    """
    min_time_step_size child of error_based_time_stepping.
    """
    max_time_step_size: max_time_step_size = max_time_step_size
    """
    max_time_step_size child of error_based_time_stepping.
    """
    min_step_change_factor: min_step_change_factor = min_step_change_factor
    """
    min_step_change_factor child of error_based_time_stepping.
    """
    max_step_change_factor: max_step_change_factor = max_step_change_factor
    """
    max_step_change_factor child of error_based_time_stepping.
    """
    update_interval: update_interval = update_interval
    """
    update_interval child of error_based_time_stepping.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class iteration_at_creation_or_edit(Integer):
    """
    'iteration_at_creation_or_edit' child.
    """

    fluent_name = "iteration-at-creation-or-edit"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mass_flow_1 import mass_flow
from .heat_transfer_1 import heat_transfer
from .heat_transfer_sensible import heat_transfer_sensible
from .rad_heat_trans import rad_heat_trans
from .film_mass_flow import film_mass_flow
from .film_heat_transfer import film_heat_transfer
from .pressure_work_1 import pressure_work
from .viscous_work import viscous_work
class fluxes(Group):
    """
    'fluxes' child.
    """

    fluent_name = "fluxes"

    command_names = \
        ['mass_flow', 'heat_transfer', 'heat_transfer_sensible',
         'rad_heat_trans', 'film_mass_flow', 'film_heat_transfer',
         'pressure_work', 'viscous_work']

    mass_flow: mass_flow = mass_flow
    """
    mass_flow command of fluxes.
    """
    heat_transfer: heat_transfer = heat_transfer
    """
    heat_transfer command of fluxes.
    """
    heat_transfer_sensible: heat_transfer_sensible = heat_transfer_sensible
    """
    heat_transfer_sensible command of fluxes.
    """
    rad_heat_trans: rad_heat_trans = rad_heat_trans
    """
    rad_heat_trans command of fluxes.
    """
    film_mass_flow: film_mass_flow = film_mass_flow
    """
    film_mass_flow command of fluxes.
    """
    film_heat_transfer: film_heat_transfer = film_heat_transfer
    """
    film_heat_transfer command of fluxes.
    """
    pressure_work: pressure_work = pressure_work
    """
    pressure_work command of fluxes.
    """
    viscous_work: viscous_work = viscous_work
    """
    viscous_work command of fluxes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class jpeg_hardcopy_quality(Integer):
    """
    0  : Saves lowest quality jpeg image, but with the least file size.
    100: Saves highest quality jpeg image, but with the maximum file size.
    """

    fluent_name = "jpeg-hardcopy-quality"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .linearization import linearization
from .implicit_momentum_coupling import implicit_momentum_coupling
from .implicit_source_term_coupling import implicit_source_term_coupling
from .linear_growth_of_dpm_source_terms import linear_growth_of_dpm_source_terms
from .reset_sources_at_timestep import reset_sources_at_timestep
from .underrelaxation_factor import underrelaxation_factor
class source_terms(Group):
    """
    'source_terms' child.
    """

    fluent_name = "source-terms"

    child_names = \
        ['linearization', 'implicit_momentum_coupling',
         'implicit_source_term_coupling', 'linear_growth_of_dpm_source_terms',
         'reset_sources_at_timestep', 'underrelaxation_factor']

    linearization: linearization = linearization
    """
    linearization child of source_terms.
    """
    implicit_momentum_coupling: implicit_momentum_coupling = implicit_momentum_coupling
    """
    implicit_momentum_coupling child of source_terms.
    """
    implicit_source_term_coupling: implicit_source_term_coupling = implicit_source_term_coupling
    """
    implicit_source_term_coupling child of source_terms.
    """
    linear_growth_of_dpm_source_terms: linear_growth_of_dpm_source_terms = linear_growth_of_dpm_source_terms
    """
    linear_growth_of_dpm_source_terms child of source_terms.
    """
    reset_sources_at_timestep: reset_sources_at_timestep = reset_sources_at_timestep
    """
    reset_sources_at_timestep child of source_terms.
    """
    underrelaxation_factor: underrelaxation_factor = underrelaxation_factor
    """
    underrelaxation_factor child of source_terms.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .material import material
from .sources import sources
from .source_terms_1 import source_terms
from .fixed import fixed
from .cylindrical_fixed_var import cylindrical_fixed_var
from .fixes import fixes
from .motion_spec import motion_spec
from .relative_to_thread import relative_to_thread
from .omega import omega
from .axis_origin_1 import axis_origin
from .axis_direction_1 import axis_direction
from .udf_zmotion_name import udf_zmotion_name
from .mrf_motion import mrf_motion
from .mrf_relative_to_thread import mrf_relative_to_thread
from .mrf_omega import mrf_omega
from .reference_frame_velocity import reference_frame_velocity
from .reference_frame_axis_origin import reference_frame_axis_origin
from .reference_frame_axis_direction import reference_frame_axis_direction
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name
from .mgrid_enable_transient import mgrid_enable_transient
from .mgrid_motion import mgrid_motion
from .mgrid_relative_to_thread import mgrid_relative_to_thread
from .mgrid_omega import mgrid_omega
from .moving_mesh_velocity import moving_mesh_velocity
from .moving_mesh_axis_origin import moving_mesh_axis_origin
from .moving_mesh_axis_direction import moving_mesh_axis_direction
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name
from .solid_motion import solid_motion
from .solid_relative_to_thread import solid_relative_to_thread
from .solid_omega import solid_omega
from .solid_motion_velocity import solid_motion_velocity
from .solid_motion_axis_origin import solid_motion_axis_origin
from .solid_motion_axis_direction import solid_motion_axis_direction
from .solid_udf_zmotion_name import solid_udf_zmotion_name
from .radiating import radiating
from .les_embedded import les_embedded
from .contact_property import contact_property
from .active_wetsteam_zone import active_wetsteam_zone
from .vapor_phase_realgas import vapor_phase_realgas
from .laminar import laminar
from .laminar_mut_zero import laminar_mut_zero
from .les_embedded_spec import les_embedded_spec
from .les_embedded_mom_scheme import les_embedded_mom_scheme
from .les_embedded_c_wale import les_embedded_c_wale
from .les_embedded_c_smag import les_embedded_c_smag
from .glass import glass
from .porous import porous
from .conical import conical
from .dir_spec_cond import dir_spec_cond
from .cursys import cursys
from .cursys_name import cursys_name
from .direction_1_x import direction_1_x
from .direction_1_y import direction_1_y
from .direction_1_z import direction_1_z
from .direction_2_x import direction_2_x
from .direction_2_y import direction_2_y
from .direction_2_z import direction_2_z
from .cone_axis_x import cone_axis_x
from .cone_axis_y import cone_axis_y
from .cone_axis_z import cone_axis_z
from .cone_axis_pt_x import cone_axis_pt_x
from .cone_axis_pt_y import cone_axis_pt_y
from .cone_axis_pt_z import cone_axis_pt_z
from .cone_angle import cone_angle
from .rel_vel_resistance import rel_vel_resistance
from .porous_r_1 import porous_r_1
from .porous_r_2 import porous_r_2
from .porous_r_3 import porous_r_3
from .alt_inertial_form import alt_inertial_form
from .porous_c_1 import porous_c_1
from .porous_c_2 import porous_c_2
from .porous_c_3 import porous_c_3
from .c0 import c0
from .c1 import c1
from .porosity import porosity
from .viscosity_ratio import viscosity_ratio
from .none import none
from .corey import corey
from .stone_1 import stone_1
from .stone_2 import stone_2
from .rel_perm_limit_p1 import rel_perm_limit_p1
from .rel_perm_limit_p2 import rel_perm_limit_p2
from .ref_perm_p1 import ref_perm_p1
from .exp_p1 import exp_p1
from .res_sat_p1 import res_sat_p1
from .ref_perm_p2 import ref_perm_p2
from .exp_p2 import exp_p2
from .res_sat_p2 import res_sat_p2
from .ref_perm_p3 import ref_perm_p3
from .exp_p3 import exp_p3
from .res_sat_p3 import res_sat_p3
from .capillary_pressure import capillary_pressure
from .max_capillary_pressure import max_capillary_pressure
from .van_genuchten_pg import van_genuchten_pg
from .van_genuchten_ng import van_genuchten_ng
from .skjaeveland_nw_pc_coef import skjaeveland_nw_pc_coef
from .skjaeveland_nw_pc_pwr import skjaeveland_nw_pc_pwr
from .skjaeveland_wet_pc_coef import skjaeveland_wet_pc_coef
from .skjaeveland_wet_pc_pwr import skjaeveland_wet_pc_pwr
from .brooks_corey_pe import brooks_corey_pe
from .brooks_corey_ng import brooks_corey_ng
from .leverett_con_ang import leverett_con_ang
from .rel_perm_tabular_p1 import rel_perm_tabular_p1
from .rel_perm_table_p1 import rel_perm_table_p1
from .rel_perm_satw_p1 import rel_perm_satw_p1
from .rel_perm_rp_p1 import rel_perm_rp_p1
from .rel_perm_tabular_p2 import rel_perm_tabular_p2
from .rel_perm_table_p2 import rel_perm_table_p2
from .rel_perm_satw_p2 import rel_perm_satw_p2
from .rel_perm_rp_p2 import rel_perm_rp_p2
from .wetting_phase import wetting_phase
from .non_wetting_phase import non_wetting_phase
from .equib_thermal import equib_thermal
from .non_equib_thermal import non_equib_thermal
from .solid_material import solid_material
from .area_density import area_density
from .heat_transfer_coeff import heat_transfer_coeff
from .fanzone import fanzone
from .fan_zone_list import fan_zone_list
from .fan_thickness import fan_thickness
from .fan_hub_rad import fan_hub_rad
from .fan_tip_rad import fan_tip_rad
from .fan_x_origin import fan_x_origin
from .fan_y_origin import fan_y_origin
from .fan_z_origin import fan_z_origin
from .fan_rot_dir import fan_rot_dir
from .fan_opert_angvel import fan_opert_angvel
from .fan_inflection_point import fan_inflection_point
from .limit_flow_fan import limit_flow_fan
from .max_flow_rate import max_flow_rate
from .min_flow_rate import min_flow_rate
from .tan_source_term import tan_source_term
from .rad_source_term import rad_source_term
from .axial_source_term import axial_source_term
from .fan_axial_source_method import fan_axial_source_method
from .fan_pre_jump import fan_pre_jump
from .fan_curve_fit import fan_curve_fit
from .fan_poly_order import fan_poly_order
from .fan_ini_flow import fan_ini_flow
from .fan_test_angvel import fan_test_angvel
from .fan_test_temp import fan_test_temp
from .reaction_mechs_1 import reaction_mechs
from .react import react
from .surface_volume_ratio import surface_volume_ratio
from .electrolyte import electrolyte
from .mp_compressive_beta_max import mp_compressive_beta_max
from .mp_boiling_zone import mp_boiling_zone
from .numerical_beach import numerical_beach
from .beach_id import beach_id
from .beach_multi_dir import beach_multi_dir
from .beach_damp_type import beach_damp_type
from .beach_inlet_bndr import beach_inlet_bndr
from .beach_fs_level import beach_fs_level
from .beach_bottom_level import beach_bottom_level
from .beach_dir_ni import beach_dir_ni
from .beach_dir_nj import beach_dir_nj
from .beach_dir_nk import beach_dir_nk
from .beach_damp_len_spec import beach_damp_len_spec
from .beach_wave_len import beach_wave_len
from .beach_len_factor import beach_len_factor
from .beach_start_point import beach_start_point
from .beach_end_point import beach_end_point
from .beach_dir_list import beach_dir_list
from .beach_damp_relative import beach_damp_relative
from .beach_damp_resist_lin import beach_damp_resist_lin
from .beach_damp_resist import beach_damp_resist
from .porous_structure import porous_structure
from .structure_material import structure_material
from .anisotropic_spe_diff import anisotropic_spe_diff
from .spe_diff_xx import spe_diff_xx
from .spe_diff_xy import spe_diff_xy
from .spe_diff_xz import spe_diff_xz
from .spe_diff_yx import spe_diff_yx
from .spe_diff_yy import spe_diff_yy
from .spe_diff_yz import spe_diff_yz
from .spe_diff_zx import spe_diff_zx
from .spe_diff_zy import spe_diff_zy
from .spe_diff_zz import spe_diff_zz
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['material', 'sources', 'source_terms', 'fixed',
         'cylindrical_fixed_var', 'fixes', 'motion_spec',
         'relative_to_thread', 'omega', 'axis_origin', 'axis_direction',
         'udf_zmotion_name', 'mrf_motion', 'mrf_relative_to_thread',
         'mrf_omega', 'reference_frame_velocity',
         'reference_frame_axis_origin', 'reference_frame_axis_direction',
         'mrf_udf_zmotion_name', 'mgrid_enable_transient', 'mgrid_motion',
         'mgrid_relative_to_thread', 'mgrid_omega', 'moving_mesh_velocity',
         'moving_mesh_axis_origin', 'moving_mesh_axis_direction',
         'mgrid_udf_zmotion_name', 'solid_motion', 'solid_relative_to_thread',
         'solid_omega', 'solid_motion_velocity', 'solid_motion_axis_origin',
         'solid_motion_axis_direction', 'solid_udf_zmotion_name', 'radiating',
         'les_embedded', 'contact_property', 'active_wetsteam_zone',
         'vapor_phase_realgas', 'laminar', 'laminar_mut_zero',
         'les_embedded_spec', 'les_embedded_mom_scheme',
         'les_embedded_c_wale', 'les_embedded_c_smag', 'glass', 'porous',
         'conical', 'dir_spec_cond', 'cursys', 'cursys_name', 'direction_1_x',
         'direction_1_y', 'direction_1_z', 'direction_2_x', 'direction_2_y',
         'direction_2_z', 'cone_axis_x', 'cone_axis_y', 'cone_axis_z',
         'cone_axis_pt_x', 'cone_axis_pt_y', 'cone_axis_pt_z', 'cone_angle',
         'rel_vel_resistance', 'porous_r_1', 'porous_r_2', 'porous_r_3',
         'alt_inertial_form', 'porous_c_1', 'porous_c_2', 'porous_c_3', 'c0',
         'c1', 'porosity', 'viscosity_ratio', 'none', 'corey', 'stone_1',
         'stone_2', 'rel_perm_limit_p1', 'rel_perm_limit_p2', 'ref_perm_p1',
         'exp_p1', 'res_sat_p1', 'ref_perm_p2', 'exp_p2', 'res_sat_p2',
         'ref_perm_p3', 'exp_p3', 'res_sat_p3', 'capillary_pressure',
         'max_capillary_pressure', 'van_genuchten_pg', 'van_genuchten_ng',
         'skjaeveland_nw_pc_coef', 'skjaeveland_nw_pc_pwr',
         'skjaeveland_wet_pc_coef', 'skjaeveland_wet_pc_pwr',
         'brooks_corey_pe', 'brooks_corey_ng', 'leverett_con_ang',
         'rel_perm_tabular_p1', 'rel_perm_table_p1', 'rel_perm_satw_p1',
         'rel_perm_rp_p1', 'rel_perm_tabular_p2', 'rel_perm_table_p2',
         'rel_perm_satw_p2', 'rel_perm_rp_p2', 'wetting_phase',
         'non_wetting_phase', 'equib_thermal', 'non_equib_thermal',
         'solid_material', 'area_density', 'heat_transfer_coeff', 'fanzone',
         'fan_zone_list', 'fan_thickness', 'fan_hub_rad', 'fan_tip_rad',
         'fan_x_origin', 'fan_y_origin', 'fan_z_origin', 'fan_rot_dir',
         'fan_opert_angvel', 'fan_inflection_point', 'limit_flow_fan',
         'max_flow_rate', 'min_flow_rate', 'tan_source_term',
         'rad_source_term', 'axial_source_term', 'fan_axial_source_method',
         'fan_pre_jump', 'fan_curve_fit', 'fan_poly_order', 'fan_ini_flow',
         'fan_test_angvel', 'fan_test_temp', 'reaction_mechs', 'react',
         'surface_volume_ratio', 'electrolyte', 'mp_compressive_beta_max',
         'mp_boiling_zone', 'numerical_beach', 'beach_id', 'beach_multi_dir',
         'beach_damp_type', 'beach_inlet_bndr', 'beach_fs_level',
         'beach_bottom_level', 'beach_dir_ni', 'beach_dir_nj', 'beach_dir_nk',
         'beach_damp_len_spec', 'beach_wave_len', 'beach_len_factor',
         'beach_start_point', 'beach_end_point', 'beach_dir_list',
         'beach_damp_relative', 'beach_damp_resist_lin', 'beach_damp_resist',
         'porous_structure', 'structure_material', 'anisotropic_spe_diff',
         'spe_diff_xx', 'spe_diff_xy', 'spe_diff_xz', 'spe_diff_yx',
         'spe_diff_yy', 'spe_diff_yz', 'spe_diff_zx', 'spe_diff_zy',
         'spe_diff_zz']

    material: material = material
    """
    material child of phase_child.
    """
    sources: sources = sources
    """
    sources child of phase_child.
    """
    source_terms: source_terms = source_terms
    """
    source_terms child of phase_child.
    """
    fixed: fixed = fixed
    """
    fixed child of phase_child.
    """
    cylindrical_fixed_var: cylindrical_fixed_var = cylindrical_fixed_var
    """
    cylindrical_fixed_var child of phase_child.
    """
    fixes: fixes = fixes
    """
    fixes child of phase_child.
    """
    motion_spec: motion_spec = motion_spec
    """
    motion_spec child of phase_child.
    """
    relative_to_thread: relative_to_thread = relative_to_thread
    """
    relative_to_thread child of phase_child.
    """
    omega: omega = omega
    """
    omega child of phase_child.
    """
    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of phase_child.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of phase_child.
    """
    udf_zmotion_name: udf_zmotion_name = udf_zmotion_name
    """
    udf_zmotion_name child of phase_child.
    """
    mrf_motion: mrf_motion = mrf_motion
    """
    mrf_motion child of phase_child.
    """
    mrf_relative_to_thread: mrf_relative_to_thread = mrf_relative_to_thread
    """
    mrf_relative_to_thread child of phase_child.
    """
    mrf_omega: mrf_omega = mrf_omega
    """
    mrf_omega child of phase_child.
    """
    reference_frame_velocity: reference_frame_velocity = reference_frame_velocity
    """
    reference_frame_velocity child of phase_child.
    """
    reference_frame_axis_origin: reference_frame_axis_origin = reference_frame_axis_origin
    """
    reference_frame_axis_origin child of phase_child.
    """
    reference_frame_axis_direction: reference_frame_axis_direction = reference_frame_axis_direction
    """
    reference_frame_axis_direction child of phase_child.
    """
    mrf_udf_zmotion_name: mrf_udf_zmotion_name = mrf_udf_zmotion_name
    """
    mrf_udf_zmotion_name child of phase_child.
    """
    mgrid_enable_transient: mgrid_enable_transient = mgrid_enable_transient
    """
    mgrid_enable_transient child of phase_child.
    """
    mgrid_motion: mgrid_motion = mgrid_motion
    """
    mgrid_motion child of phase_child.
    """
    mgrid_relative_to_thread: mgrid_relative_to_thread = mgrid_relative_to_thread
    """
    mgrid_relative_to_thread child of phase_child.
    """
    mgrid_omega: mgrid_omega = mgrid_omega
    """
    mgrid_omega child of phase_child.
    """
    moving_mesh_velocity: moving_mesh_velocity = moving_mesh_velocity
    """
    moving_mesh_velocity child of phase_child.
    """
    moving_mesh_axis_origin: moving_mesh_axis_origin = moving_mesh_axis_origin
    """
    moving_mesh_axis_origin child of phase_child.
    """
    moving_mesh_axis_direction: moving_mesh_axis_direction = moving_mesh_axis_direction
    """
    moving_mesh_axis_direction child of phase_child.
    """
    mgrid_udf_zmotion_name: mgrid_udf_zmotion_name = mgrid_udf_zmotion_name
    """
    mgrid_udf_zmotion_name child of phase_child.
    """
    solid_motion: solid_motion = solid_motion
    """
    solid_motion child of phase_child.
    """
    solid_relative_to_thread: solid_relative_to_thread = solid_relative_to_thread
    """
    solid_relative_to_thread child of phase_child.
    """
    solid_omega: solid_omega = solid_omega
    """
    solid_omega child of phase_child.
    """
    solid_motion_velocity: solid_motion_velocity = solid_motion_velocity
    """
    solid_motion_velocity child of phase_child.
    """
    solid_motion_axis_origin: solid_motion_axis_origin = solid_motion_axis_origin
    """
    solid_motion_axis_origin child of phase_child.
    """
    solid_motion_axis_direction: solid_motion_axis_direction = solid_motion_axis_direction
    """
    solid_motion_axis_direction child of phase_child.
    """
    solid_udf_zmotion_name: solid_udf_zmotion_name = solid_udf_zmotion_name
    """
    solid_udf_zmotion_name child of phase_child.
    """
    radiating: radiating = radiating
    """
    radiating child of phase_child.
    """
    les_embedded: les_embedded = les_embedded
    """
    les_embedded child of phase_child.
    """
    contact_property: contact_property = contact_property
    """
    contact_property child of phase_child.
    """
    active_wetsteam_zone: active_wetsteam_zone = active_wetsteam_zone
    """
    active_wetsteam_zone child of phase_child.
    """
    vapor_phase_realgas: vapor_phase_realgas = vapor_phase_realgas
    """
    vapor_phase_realgas child of phase_child.
    """
    laminar: laminar = laminar
    """
    laminar child of phase_child.
    """
    laminar_mut_zero: laminar_mut_zero = laminar_mut_zero
    """
    laminar_mut_zero child of phase_child.
    """
    les_embedded_spec: les_embedded_spec = les_embedded_spec
    """
    les_embedded_spec child of phase_child.
    """
    les_embedded_mom_scheme: les_embedded_mom_scheme = les_embedded_mom_scheme
    """
    les_embedded_mom_scheme child of phase_child.
    """
    les_embedded_c_wale: les_embedded_c_wale = les_embedded_c_wale
    """
    les_embedded_c_wale child of phase_child.
    """
    les_embedded_c_smag: les_embedded_c_smag = les_embedded_c_smag
    """
    les_embedded_c_smag child of phase_child.
    """
    glass: glass = glass
    """
    glass child of phase_child.
    """
    porous: porous = porous
    """
    porous child of phase_child.
    """
    conical: conical = conical
    """
    conical child of phase_child.
    """
    dir_spec_cond: dir_spec_cond = dir_spec_cond
    """
    dir_spec_cond child of phase_child.
    """
    cursys: cursys = cursys
    """
    cursys child of phase_child.
    """
    cursys_name: cursys_name = cursys_name
    """
    cursys_name child of phase_child.
    """
    direction_1_x: direction_1_x = direction_1_x
    """
    direction_1_x child of phase_child.
    """
    direction_1_y: direction_1_y = direction_1_y
    """
    direction_1_y child of phase_child.
    """
    direction_1_z: direction_1_z = direction_1_z
    """
    direction_1_z child of phase_child.
    """
    direction_2_x: direction_2_x = direction_2_x
    """
    direction_2_x child of phase_child.
    """
    direction_2_y: direction_2_y = direction_2_y
    """
    direction_2_y child of phase_child.
    """
    direction_2_z: direction_2_z = direction_2_z
    """
    direction_2_z child of phase_child.
    """
    cone_axis_x: cone_axis_x = cone_axis_x
    """
    cone_axis_x child of phase_child.
    """
    cone_axis_y: cone_axis_y = cone_axis_y
    """
    cone_axis_y child of phase_child.
    """
    cone_axis_z: cone_axis_z = cone_axis_z
    """
    cone_axis_z child of phase_child.
    """
    cone_axis_pt_x: cone_axis_pt_x = cone_axis_pt_x
    """
    cone_axis_pt_x child of phase_child.
    """
    cone_axis_pt_y: cone_axis_pt_y = cone_axis_pt_y
    """
    cone_axis_pt_y child of phase_child.
    """
    cone_axis_pt_z: cone_axis_pt_z = cone_axis_pt_z
    """
    cone_axis_pt_z child of phase_child.
    """
    cone_angle: cone_angle = cone_angle
    """
    cone_angle child of phase_child.
    """
    rel_vel_resistance: rel_vel_resistance = rel_vel_resistance
    """
    rel_vel_resistance child of phase_child.
    """
    porous_r_1: porous_r_1 = porous_r_1
    """
    porous_r_1 child of phase_child.
    """
    porous_r_2: porous_r_2 = porous_r_2
    """
    porous_r_2 child of phase_child.
    """
    porous_r_3: porous_r_3 = porous_r_3
    """
    porous_r_3 child of phase_child.
    """
    alt_inertial_form: alt_inertial_form = alt_inertial_form
    """
    alt_inertial_form child of phase_child.
    """
    porous_c_1: porous_c_1 = porous_c_1
    """
    porous_c_1 child of phase_child.
    """
    porous_c_2: porous_c_2 = porous_c_2
    """
    porous_c_2 child of phase_child.
    """
    porous_c_3: porous_c_3 = porous_c_3
    """
    porous_c_3 child of phase_child.
    """
    c0: c0 = c0
    """
    c0 child of phase_child.
    """
    c1: c1 = c1
    """
    c1 child of phase_child.
    """
    porosity: porosity = porosity
    """
    porosity child of phase_child.
    """
    viscosity_ratio: viscosity_ratio = viscosity_ratio
    """
    viscosity_ratio child of phase_child.
    """
    none: none = none
    """
    none child of phase_child.
    """
    corey: corey = corey
    """
    corey child of phase_child.
    """
    stone_1: stone_1 = stone_1
    """
    stone_1 child of phase_child.
    """
    stone_2: stone_2 = stone_2
    """
    stone_2 child of phase_child.
    """
    rel_perm_limit_p1: rel_perm_limit_p1 = rel_perm_limit_p1
    """
    rel_perm_limit_p1 child of phase_child.
    """
    rel_perm_limit_p2: rel_perm_limit_p2 = rel_perm_limit_p2
    """
    rel_perm_limit_p2 child of phase_child.
    """
    ref_perm_p1: ref_perm_p1 = ref_perm_p1
    """
    ref_perm_p1 child of phase_child.
    """
    exp_p1: exp_p1 = exp_p1
    """
    exp_p1 child of phase_child.
    """
    res_sat_p1: res_sat_p1 = res_sat_p1
    """
    res_sat_p1 child of phase_child.
    """
    ref_perm_p2: ref_perm_p2 = ref_perm_p2
    """
    ref_perm_p2 child of phase_child.
    """
    exp_p2: exp_p2 = exp_p2
    """
    exp_p2 child of phase_child.
    """
    res_sat_p2: res_sat_p2 = res_sat_p2
    """
    res_sat_p2 child of phase_child.
    """
    ref_perm_p3: ref_perm_p3 = ref_perm_p3
    """
    ref_perm_p3 child of phase_child.
    """
    exp_p3: exp_p3 = exp_p3
    """
    exp_p3 child of phase_child.
    """
    res_sat_p3: res_sat_p3 = res_sat_p3
    """
    res_sat_p3 child of phase_child.
    """
    capillary_pressure: capillary_pressure = capillary_pressure
    """
    capillary_pressure child of phase_child.
    """
    max_capillary_pressure: max_capillary_pressure = max_capillary_pressure
    """
    max_capillary_pressure child of phase_child.
    """
    van_genuchten_pg: van_genuchten_pg = van_genuchten_pg
    """
    van_genuchten_pg child of phase_child.
    """
    van_genuchten_ng: van_genuchten_ng = van_genuchten_ng
    """
    van_genuchten_ng child of phase_child.
    """
    skjaeveland_nw_pc_coef: skjaeveland_nw_pc_coef = skjaeveland_nw_pc_coef
    """
    skjaeveland_nw_pc_coef child of phase_child.
    """
    skjaeveland_nw_pc_pwr: skjaeveland_nw_pc_pwr = skjaeveland_nw_pc_pwr
    """
    skjaeveland_nw_pc_pwr child of phase_child.
    """
    skjaeveland_wet_pc_coef: skjaeveland_wet_pc_coef = skjaeveland_wet_pc_coef
    """
    skjaeveland_wet_pc_coef child of phase_child.
    """
    skjaeveland_wet_pc_pwr: skjaeveland_wet_pc_pwr = skjaeveland_wet_pc_pwr
    """
    skjaeveland_wet_pc_pwr child of phase_child.
    """
    brooks_corey_pe: brooks_corey_pe = brooks_corey_pe
    """
    brooks_corey_pe child of phase_child.
    """
    brooks_corey_ng: brooks_corey_ng = brooks_corey_ng
    """
    brooks_corey_ng child of phase_child.
    """
    leverett_con_ang: leverett_con_ang = leverett_con_ang
    """
    leverett_con_ang child of phase_child.
    """
    rel_perm_tabular_p1: rel_perm_tabular_p1 = rel_perm_tabular_p1
    """
    rel_perm_tabular_p1 child of phase_child.
    """
    rel_perm_table_p1: rel_perm_table_p1 = rel_perm_table_p1
    """
    rel_perm_table_p1 child of phase_child.
    """
    rel_perm_satw_p1: rel_perm_satw_p1 = rel_perm_satw_p1
    """
    rel_perm_satw_p1 child of phase_child.
    """
    rel_perm_rp_p1: rel_perm_rp_p1 = rel_perm_rp_p1
    """
    rel_perm_rp_p1 child of phase_child.
    """
    rel_perm_tabular_p2: rel_perm_tabular_p2 = rel_perm_tabular_p2
    """
    rel_perm_tabular_p2 child of phase_child.
    """
    rel_perm_table_p2: rel_perm_table_p2 = rel_perm_table_p2
    """
    rel_perm_table_p2 child of phase_child.
    """
    rel_perm_satw_p2: rel_perm_satw_p2 = rel_perm_satw_p2
    """
    rel_perm_satw_p2 child of phase_child.
    """
    rel_perm_rp_p2: rel_perm_rp_p2 = rel_perm_rp_p2
    """
    rel_perm_rp_p2 child of phase_child.
    """
    wetting_phase: wetting_phase = wetting_phase
    """
    wetting_phase child of phase_child.
    """
    non_wetting_phase: non_wetting_phase = non_wetting_phase
    """
    non_wetting_phase child of phase_child.
    """
    equib_thermal: equib_thermal = equib_thermal
    """
    equib_thermal child of phase_child.
    """
    non_equib_thermal: non_equib_thermal = non_equib_thermal
    """
    non_equib_thermal child of phase_child.
    """
    solid_material: solid_material = solid_material
    """
    solid_material child of phase_child.
    """
    area_density: area_density = area_density
    """
    area_density child of phase_child.
    """
    heat_transfer_coeff: heat_transfer_coeff = heat_transfer_coeff
    """
    heat_transfer_coeff child of phase_child.
    """
    fanzone: fanzone = fanzone
    """
    fanzone child of phase_child.
    """
    fan_zone_list: fan_zone_list = fan_zone_list
    """
    fan_zone_list child of phase_child.
    """
    fan_thickness: fan_thickness = fan_thickness
    """
    fan_thickness child of phase_child.
    """
    fan_hub_rad: fan_hub_rad = fan_hub_rad
    """
    fan_hub_rad child of phase_child.
    """
    fan_tip_rad: fan_tip_rad = fan_tip_rad
    """
    fan_tip_rad child of phase_child.
    """
    fan_x_origin: fan_x_origin = fan_x_origin
    """
    fan_x_origin child of phase_child.
    """
    fan_y_origin: fan_y_origin = fan_y_origin
    """
    fan_y_origin child of phase_child.
    """
    fan_z_origin: fan_z_origin = fan_z_origin
    """
    fan_z_origin child of phase_child.
    """
    fan_rot_dir: fan_rot_dir = fan_rot_dir
    """
    fan_rot_dir child of phase_child.
    """
    fan_opert_angvel: fan_opert_angvel = fan_opert_angvel
    """
    fan_opert_angvel child of phase_child.
    """
    fan_inflection_point: fan_inflection_point = fan_inflection_point
    """
    fan_inflection_point child of phase_child.
    """
    limit_flow_fan: limit_flow_fan = limit_flow_fan
    """
    limit_flow_fan child of phase_child.
    """
    max_flow_rate: max_flow_rate = max_flow_rate
    """
    max_flow_rate child of phase_child.
    """
    min_flow_rate: min_flow_rate = min_flow_rate
    """
    min_flow_rate child of phase_child.
    """
    tan_source_term: tan_source_term = tan_source_term
    """
    tan_source_term child of phase_child.
    """
    rad_source_term: rad_source_term = rad_source_term
    """
    rad_source_term child of phase_child.
    """
    axial_source_term: axial_source_term = axial_source_term
    """
    axial_source_term child of phase_child.
    """
    fan_axial_source_method: fan_axial_source_method = fan_axial_source_method
    """
    fan_axial_source_method child of phase_child.
    """
    fan_pre_jump: fan_pre_jump = fan_pre_jump
    """
    fan_pre_jump child of phase_child.
    """
    fan_curve_fit: fan_curve_fit = fan_curve_fit
    """
    fan_curve_fit child of phase_child.
    """
    fan_poly_order: fan_poly_order = fan_poly_order
    """
    fan_poly_order child of phase_child.
    """
    fan_ini_flow: fan_ini_flow = fan_ini_flow
    """
    fan_ini_flow child of phase_child.
    """
    fan_test_angvel: fan_test_angvel = fan_test_angvel
    """
    fan_test_angvel child of phase_child.
    """
    fan_test_temp: fan_test_temp = fan_test_temp
    """
    fan_test_temp child of phase_child.
    """
    reaction_mechs: reaction_mechs = reaction_mechs
    """
    reaction_mechs child of phase_child.
    """
    react: react = react
    """
    react child of phase_child.
    """
    surface_volume_ratio: surface_volume_ratio = surface_volume_ratio
    """
    surface_volume_ratio child of phase_child.
    """
    electrolyte: electrolyte = electrolyte
    """
    electrolyte child of phase_child.
    """
    mp_compressive_beta_max: mp_compressive_beta_max = mp_compressive_beta_max
    """
    mp_compressive_beta_max child of phase_child.
    """
    mp_boiling_zone: mp_boiling_zone = mp_boiling_zone
    """
    mp_boiling_zone child of phase_child.
    """
    numerical_beach: numerical_beach = numerical_beach
    """
    numerical_beach child of phase_child.
    """
    beach_id: beach_id = beach_id
    """
    beach_id child of phase_child.
    """
    beach_multi_dir: beach_multi_dir = beach_multi_dir
    """
    beach_multi_dir child of phase_child.
    """
    beach_damp_type: beach_damp_type = beach_damp_type
    """
    beach_damp_type child of phase_child.
    """
    beach_inlet_bndr: beach_inlet_bndr = beach_inlet_bndr
    """
    beach_inlet_bndr child of phase_child.
    """
    beach_fs_level: beach_fs_level = beach_fs_level
    """
    beach_fs_level child of phase_child.
    """
    beach_bottom_level: beach_bottom_level = beach_bottom_level
    """
    beach_bottom_level child of phase_child.
    """
    beach_dir_ni: beach_dir_ni = beach_dir_ni
    """
    beach_dir_ni child of phase_child.
    """
    beach_dir_nj: beach_dir_nj = beach_dir_nj
    """
    beach_dir_nj child of phase_child.
    """
    beach_dir_nk: beach_dir_nk = beach_dir_nk
    """
    beach_dir_nk child of phase_child.
    """
    beach_damp_len_spec: beach_damp_len_spec = beach_damp_len_spec
    """
    beach_damp_len_spec child of phase_child.
    """
    beach_wave_len: beach_wave_len = beach_wave_len
    """
    beach_wave_len child of phase_child.
    """
    beach_len_factor: beach_len_factor = beach_len_factor
    """
    beach_len_factor child of phase_child.
    """
    beach_start_point: beach_start_point = beach_start_point
    """
    beach_start_point child of phase_child.
    """
    beach_end_point: beach_end_point = beach_end_point
    """
    beach_end_point child of phase_child.
    """
    beach_dir_list: beach_dir_list = beach_dir_list
    """
    beach_dir_list child of phase_child.
    """
    beach_damp_relative: beach_damp_relative = beach_damp_relative
    """
    beach_damp_relative child of phase_child.
    """
    beach_damp_resist_lin: beach_damp_resist_lin = beach_damp_resist_lin
    """
    beach_damp_resist_lin child of phase_child.
    """
    beach_damp_resist: beach_damp_resist = beach_damp_resist
    """
    beach_damp_resist child of phase_child.
    """
    porous_structure: porous_structure = porous_structure
    """
    porous_structure child of phase_child.
    """
    structure_material: structure_material = structure_material
    """
    structure_material child of phase_child.
    """
    anisotropic_spe_diff: anisotropic_spe_diff = anisotropic_spe_diff
    """
    anisotropic_spe_diff child of phase_child.
    """
    spe_diff_xx: spe_diff_xx = spe_diff_xx
    """
    spe_diff_xx child of phase_child.
    """
    spe_diff_xy: spe_diff_xy = spe_diff_xy
    """
    spe_diff_xy child of phase_child.
    """
    spe_diff_xz: spe_diff_xz = spe_diff_xz
    """
    spe_diff_xz child of phase_child.
    """
    spe_diff_yx: spe_diff_yx = spe_diff_yx
    """
    spe_diff_yx child of phase_child.
    """
    spe_diff_yy: spe_diff_yy = spe_diff_yy
    """
    spe_diff_yy child of phase_child.
    """
    spe_diff_yz: spe_diff_yz = spe_diff_yz
    """
    spe_diff_yz child of phase_child.
    """
    spe_diff_zx: spe_diff_zx = spe_diff_zx
    """
    spe_diff_zx child of phase_child.
    """
    spe_diff_zy: spe_diff_zy = spe_diff_zy
    """
    spe_diff_zy child of phase_child.
    """
    spe_diff_zz: spe_diff_zz = spe_diff_zz
    """
    spe_diff_zz child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .field import field
from .filled import filled
from .boundary_values import boundary_values
from .contour_lines import contour_lines
from .node_values import node_values
from .surfaces_list import surfaces_list
from .range_option import range_option
from .coloring import coloring
from .color_map import color_map
from .draw_mesh import draw_mesh
from .mesh_object import mesh_object
from .display_state_name import display_state_name
from .physics import physics
from .geometry_3 import geometry
from .surfaces import surfaces
from .deformation import deformation
from .deformation_scale import deformation_scale
from .display_2 import display
class contour_child(Group):
    """
    'child_object_type' of contour.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'filled', 'boundary_values', 'contour_lines',
         'node_values', 'surfaces_list', 'range_option', 'coloring',
         'color_map', 'draw_mesh', 'mesh_object', 'display_state_name',
         'physics', 'geometry', 'surfaces', 'deformation',
         'deformation_scale']

    name: name = name
    """
    name child of contour_child.
    """
    field: field = field
    """
    field child of contour_child.
    """
    filled: filled = filled
    """
    filled child of contour_child.
    """
    boundary_values: boundary_values = boundary_values
    """
    boundary_values child of contour_child.
    """
    contour_lines: contour_lines = contour_lines
    """
    contour_lines child of contour_child.
    """
    node_values: node_values = node_values
    """
    node_values child of contour_child.
    """
    surfaces_list: surfaces_list = surfaces_list
    """
    surfaces_list child of contour_child.
    """
    range_option: range_option = range_option
    """
    range_option child of contour_child.
    """
    coloring: coloring = coloring
    """
    coloring child of contour_child.
    """
    color_map: color_map = color_map
    """
    color_map child of contour_child.
    """
    draw_mesh: draw_mesh = draw_mesh
    """
    draw_mesh child of contour_child.
    """
    mesh_object: mesh_object = mesh_object
    """
    mesh_object child of contour_child.
    """
    display_state_name: display_state_name = display_state_name
    """
    display_state_name child of contour_child.
    """
    physics: physics = physics
    """
    physics child of contour_child.
    """
    geometry: geometry = geometry
    """
    geometry child of contour_child.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of contour_child.
    """
    deformation: deformation = deformation
    """
    deformation child of contour_child.
    """
    deformation_scale: deformation_scale = deformation_scale
    """
    deformation_scale child of contour_child.
    """
    command_names = \
        ['display']

    display: display = display
    """
    display command of contour_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .interface_child import interface_child

class interface(NamedObject[interface_child], _NonCreatableNamedObjectMixin[interface_child]):
    """
    'interface' child.
    """

    fluent_name = "interface"

    child_object_type: interface_child = interface_child
    """
    child_object_type of interface.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .relaxation_bounding_method import relaxation_bounding_method
from .default_min_max_relaxation_limits import default_min_max_relaxation_limits
from .minimum_allowed_effctive_relaxation import minimum_allowed_effctive_relaxation
from .maximum_allowed_effctive_relaxation import maximum_allowed_effctive_relaxation
class relaxation_bounds(Command):
    """
    Select relaxation bounding scheme for pseudo time method.
    
    Parameters
    ----------
        relaxation_bounding_method : str
            'relaxation_bounding_method' child.
        default_min_max_relaxation_limits : bool
            'default_min_max_relaxation_limits' child.
        minimum_allowed_effctive_relaxation : real
            'minimum_allowed_effctive_relaxation' child.
        maximum_allowed_effctive_relaxation : real
            'maximum_allowed_effctive_relaxation' child.
    
    """

    fluent_name = "relaxation-bounds"

    argument_names = \
        ['relaxation_bounding_method', 'default_min_max_relaxation_limits',
         'minimum_allowed_effctive_relaxation',
         'maximum_allowed_effctive_relaxation']

    relaxation_bounding_method: relaxation_bounding_method = relaxation_bounding_method
    """
    relaxation_bounding_method argument of relaxation_bounds.
    """
    default_min_max_relaxation_limits: default_min_max_relaxation_limits = default_min_max_relaxation_limits
    """
    default_min_max_relaxation_limits argument of relaxation_bounds.
    """
    minimum_allowed_effctive_relaxation: minimum_allowed_effctive_relaxation = minimum_allowed_effctive_relaxation
    """
    minimum_allowed_effctive_relaxation argument of relaxation_bounds.
    """
    maximum_allowed_effctive_relaxation: maximum_allowed_effctive_relaxation = maximum_allowed_effctive_relaxation
    """
    maximum_allowed_effctive_relaxation argument of relaxation_bounds.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fixed_periodic import fixed_periodic
from .fixed_periodic_type import fixed_periodic_type
from .fixed_periodic_type_value import fixed_periodic_type_value
from .times_step_periods import times_step_periods
from .total_period_run import total_period_run
class fixed_periodic(Group):
    """
    'fixed_periodic' child.
    """

    fluent_name = "fixed-periodic"

    child_names = \
        ['fixed_periodic', 'fixed_periodic_type', 'fixed_periodic_type_value',
         'times_step_periods', 'total_period_run']

    fixed_periodic: fixed_periodic = fixed_periodic
    """
    fixed_periodic child of fixed_periodic.
    """
    fixed_periodic_type: fixed_periodic_type = fixed_periodic_type
    """
    fixed_periodic_type child of fixed_periodic.
    """
    fixed_periodic_type_value: fixed_periodic_type_value = fixed_periodic_type_value
    """
    fixed_periodic_type_value child of fixed_periodic.
    """
    times_step_periods: times_step_periods = times_step_periods
    """
    times_step_periods child of fixed_periodic.
    """
    total_period_run: total_period_run = total_period_run
    """
    total_period_run child of fixed_periodic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pseudo_time_courant_number import pseudo_time_courant_number
from .pseudo_time_step_method_solid_zone import pseudo_time_step_method_solid_zone
from .time_step_size_scale_factor import time_step_size_scale_factor
class pseudo_time_method_local_time_step(Group):
    """
    'pseudo_time_method_local_time_step' child.
    """

    fluent_name = "pseudo-time-method-local-time-step"

    child_names = \
        ['pseudo_time_courant_number', 'pseudo_time_step_method_solid_zone',
         'time_step_size_scale_factor']

    pseudo_time_courant_number: pseudo_time_courant_number = pseudo_time_courant_number
    """
    pseudo_time_courant_number child of pseudo_time_method_local_time_step.
    """
    pseudo_time_step_method_solid_zone: pseudo_time_step_method_solid_zone = pseudo_time_step_method_solid_zone
    """
    pseudo_time_step_method_solid_zone child of pseudo_time_method_local_time_step.
    """
    time_step_size_scale_factor: time_step_size_scale_factor = time_step_size_scale_factor
    """
    time_step_size_scale_factor child of pseudo_time_method_local_time_step.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .check_reduction_wt import check_reduction_wt
from .file_name_1 import file_name
from .overwrite import overwrite
class reduce_picked_sample(Command):
    """
    Reduce a sample after first picking it and setting up all data-reduction options and parameters.
    
    Parameters
    ----------
        check_reduction_wt : bool
            'check_reduction_wt' child.
        file_name : str
            'file_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "reduce-picked-sample"

    argument_names = \
        ['check_reduction_wt', 'file_name', 'overwrite']

    check_reduction_wt: check_reduction_wt = check_reduction_wt
    """
    check_reduction_wt argument of reduce_picked_sample.
    """
    file_name: file_name = file_name
    """
    file_name argument of reduce_picked_sample.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of reduce_picked_sample.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_7 import enable
from .options_4 import options
class multi_phase_setting(Group):
    """
    'multi_phase_setting' child.
    """

    fluent_name = "multi-phase-setting"

    child_names = \
        ['enable', 'options']

    enable: enable = enable
    """
    enable child of multi_phase_setting.
    """
    options: options = options
    """
    options child of multi_phase_setting.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .sample_var import sample_var
from .max_val import max_val
class set_maximum(Command):
    """
    'set_maximum' command.
    
    Parameters
    ----------
        sample_var : str
            'sample_var' child.
        max_val : real
            'max_val' child.
    
    """

    fluent_name = "set-maximum"

    argument_names = \
        ['sample_var', 'max_val']

    sample_var: sample_var = sample_var
    """
    sample_var argument of set_maximum.
    """
    max_val: max_val = max_val
    """
    max_val argument of set_maximum.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .formulation import formulation
from .relaxation_method_1 import relaxation_method
from .convergence_acceleration_for_stretched_meshes_1 import convergence_acceleration_for_stretched_meshes
from .relaxation_bounds import relaxation_bounds
class pseudo_time_method(Group):
    """
    Enter the pseudo time method menu.
    """

    fluent_name = "pseudo-time-method"

    child_names = \
        ['formulation', 'relaxation_method',
         'convergence_acceleration_for_stretched_meshes']

    formulation: formulation = formulation
    """
    formulation child of pseudo_time_method.
    """
    relaxation_method: relaxation_method = relaxation_method
    """
    relaxation_method child of pseudo_time_method.
    """
    convergence_acceleration_for_stretched_meshes: convergence_acceleration_for_stretched_meshes = convergence_acceleration_for_stretched_meshes
    """
    convergence_acceleration_for_stretched_meshes child of pseudo_time_method.
    """
    command_names = \
        ['relaxation_bounds']

    relaxation_bounds: relaxation_bounds = relaxation_bounds
    """
    relaxation_bounds command of pseudo_time_method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .time_constant import time_constant
from .power_law_index import power_law_index
from .zero_shear_viscosity import zero_shear_viscosity
from .infinite_shear_viscosity import infinite_shear_viscosity
from .reference_temperature import reference_temperature
from .activation_energy import activation_energy
class carreau(Group):
    """
    'carreau' child.
    """

    fluent_name = "carreau"

    child_names = \
        ['option', 'time_constant', 'power_law_index', 'zero_shear_viscosity',
         'infinite_shear_viscosity', 'reference_temperature',
         'activation_energy']

    option: option = option
    """
    option child of carreau.
    """
    time_constant: time_constant = time_constant
    """
    time_constant child of carreau.
    """
    power_law_index: power_law_index = power_law_index
    """
    power_law_index child of carreau.
    """
    zero_shear_viscosity: zero_shear_viscosity = zero_shear_viscosity
    """
    zero_shear_viscosity child of carreau.
    """
    infinite_shear_viscosity: infinite_shear_viscosity = infinite_shear_viscosity
    """
    infinite_shear_viscosity child of carreau.
    """
    reference_temperature: reference_temperature = reference_temperature
    """
    reference_temperature child of carreau.
    """
    activation_energy: activation_energy = activation_energy
    """
    activation_energy child of carreau.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .partition_method import partition_method
from .count import count
class method(Command):
    """
    Partition the domain.
    
    Parameters
    ----------
        partition_method : str
            'partition_method' child.
        count : int
            'count' child.
    
    """

    fluent_name = "method"

    argument_names = \
        ['partition_method', 'count']

    partition_method: partition_method = partition_method
    """
    partition_method argument of method.
    """
    count: count = count
    """
    count argument of method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .multicomponent_child import multicomponent_child

class multicomponent(NamedObject[multicomponent_child], _NonCreatableNamedObjectMixin[multicomponent_child]):
    """
    'multicomponent' child.
    """

    fluent_name = "multicomponent"

    child_object_type: multicomponent_child = multicomponent_child
    """
    child_object_type of multicomponent.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .database_type import database_type
from .copy_by_formula import copy_by_formula
from .copy_by_name import copy_by_name
from .list_materials import list_materials
from .list_properties import list_properties
class database(Group):
    """
    'database' child.
    """

    fluent_name = "database"

    child_names = \
        ['database_type']

    database_type: database_type = database_type
    """
    database_type child of database.
    """
    command_names = \
        ['copy_by_formula', 'copy_by_name', 'list_materials',
         'list_properties']

    copy_by_formula: copy_by_formula = copy_by_formula
    """
    copy_by_formula command of database.
    """
    copy_by_name: copy_by_name = copy_by_name
    """
    copy_by_name command of database.
    """
    list_materials: list_materials = list_materials
    """
    list_materials command of database.
    """
    list_properties: list_properties = list_properties
    """
    list_properties command of database.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class explicit_relaxation_factor(Real):
    """
    Specify explicit relaxation factor to be applied to
    the solution correction when updating solution in the timestep iterations.
    """

    fluent_name = "explicit-relaxation-factor"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .scale_2 import scale
from .sphere_lod import sphere_lod
from .options_9 import options
class sphere_settings(Group):
    """
    'sphere_settings' child.
    """

    fluent_name = "sphere-settings"

    child_names = \
        ['scale', 'sphere_lod', 'options']

    scale: scale = scale
    """
    scale child of sphere_settings.
    """
    sphere_lod: sphere_lod = sphere_lod
    """
    sphere_lod child of sphere_settings.
    """
    options: options = options
    """
    options child of sphere_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .diameter import diameter
class constant(Group):
    """
    'constant' child.
    """

    fluent_name = "constant"

    child_names = \
        ['diameter']

    diameter: diameter = diameter
    """
    diameter child of constant.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .change_type import change_type
from .inlet_vent_child import inlet_vent_child

class inlet_vent(NamedObject[inlet_vent_child], _CreatableNamedObjectMixin[inlet_vent_child]):
    """
    'inlet_vent' child.
    """

    fluent_name = "inlet-vent"

    command_names = \
        ['change_type']

    change_type: change_type = change_type
    """
    change_type command of inlet_vent.
    """
    child_object_type: inlet_vent_child = inlet_vent_child
    """
    child_object_type of inlet_vent.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .rgb_vector import rgb_vector
class set_ambient_color(Command):
    """
    'set_ambient_color' command.
    
    Parameters
    ----------
        rgb_vector : typing.Tuple[real, real, real]
            'rgb_vector' child.
    
    """

    fluent_name = "set-ambient-color"

    argument_names = \
        ['rgb_vector']

    rgb_vector: rgb_vector = rgb_vector
    """
    rgb_vector argument of set_ambient_color.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class max_rel_humidity(Real):
    """
    Maximum value of relative humidity to limit condensation rate.
    """

    fluent_name = "max-rel-humidity"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_8 import option
from .max_vf_allowed_for_blocking import max_vf_allowed_for_blocking
from .enable_drag_scaling import enable_drag_scaling
from .enable_source_term_scaling import enable_source_term_scaling
class volume_displacement(Group):
    """
    In many Lagrangian-Eulerian simulations, the volume fraction of the local particle phase may not be small,
    and the blocking effect of the particulate phase on the carrier phase may need to be taken into account.
    To enable the volume displacement effect of particles, select "option = #t".
    """

    fluent_name = "volume-displacement"

    child_names = \
        ['option', 'max_vf_allowed_for_blocking', 'enable_drag_scaling',
         'enable_source_term_scaling']

    option: option = option
    """
    option child of volume_displacement.
    """
    max_vf_allowed_for_blocking: max_vf_allowed_for_blocking = max_vf_allowed_for_blocking
    """
    max_vf_allowed_for_blocking child of volume_displacement.
    """
    enable_drag_scaling: enable_drag_scaling = enable_drag_scaling
    """
    enable_drag_scaling child of volume_displacement.
    """
    enable_source_term_scaling: enable_source_term_scaling = enable_source_term_scaling
    """
    enable_source_term_scaling child of volume_displacement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .repair_1 import repair
class repair_wall_distance(Command):
    """
    Correct wall distance at very high aspect ratio hexahedral/polyhedral cells.
    
    Parameters
    ----------
        repair : bool
            'repair' child.
    
    """

    fluent_name = "repair-wall-distance"

    argument_names = \
        ['repair']

    repair: repair = repair
    """
    repair argument of repair_wall_distance.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .general_settings import general_settings
from .turbulent_setting import turbulent_setting
class set_hybrid_init_options(Group):
    """
    'set_hybrid_init_options' child.
    """

    fluent_name = "set-hybrid-init-options"

    child_names = \
        ['general_settings', 'turbulent_setting']

    general_settings: general_settings = general_settings
    """
    general_settings child of set_hybrid_init_options.
    """
    turbulent_setting: turbulent_setting = turbulent_setting
    """
    turbulent_setting child of set_hybrid_init_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name import name
from .zones import zones
class replace(Command):
    """
    Replace mesh and interpolate data.
    
    Parameters
    ----------
        name : str
            'name' child.
        zones : bool
            'zones' child.
    
    """

    fluent_name = "replace"

    argument_names = \
        ['name', 'zones']

    name: name = name
    """
    name argument of replace.
    """
    zones: zones = zones
    """
    zones argument of replace.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .load_balancing import load_balancing
from .threshold import threshold
from .interval import interval
class dpm_load_balancing(Group):
    """
    Enable automatic load balancing for DPM.
    """

    fluent_name = "dpm-load-balancing"

    child_names = \
        ['load_balancing', 'threshold', 'interval']

    load_balancing: load_balancing = load_balancing
    """
    load_balancing child of dpm_load_balancing.
    """
    threshold: threshold = threshold
    """
    threshold child of dpm_load_balancing.
    """
    interval: interval = interval
    """
    interval child of dpm_load_balancing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .user_specified_origin_and_axis import user_specified_origin_and_axis
from .origin_1 import origin
from .axis_1 import axis
from .mass_criterion import mass_criterion
from .physics import physics
from .boundary_zones_names import boundary_zones_names
from .boundary_zones_1 import boundary_zones
from .retain_instantaneous_values import retain_instantaneous_values
from .inj_mass_rate_last_tstp import inj_mass_rate_last_tstp
from .inj_mass_rate_last_flow import inj_mass_rate_last_flow
from .inj_mass_rate_prev_mass import inj_mass_rate_prev_mass
from .inj_mass_rate_prev_time import inj_mass_rate_prev_time
from .show_unsteady_rate import show_unsteady_rate
from .old_props import old_props
from .average_over import average_over
from .per_injection import per_injection
from .injection_list import injection_list
class injection_child(Group):
    """
    'child_object_type' of injection.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['report_type', 'user_specified_origin_and_axis', 'origin', 'axis',
         'mass_criterion', 'physics', 'boundary_zones_names',
         'boundary_zones', 'retain_instantaneous_values',
         'inj_mass_rate_last_tstp', 'inj_mass_rate_last_flow',
         'inj_mass_rate_prev_mass', 'inj_mass_rate_prev_time',
         'show_unsteady_rate', 'old_props', 'average_over', 'per_injection',
         'injection_list']

    report_type: report_type = report_type
    """
    report_type child of injection_child.
    """
    user_specified_origin_and_axis: user_specified_origin_and_axis = user_specified_origin_and_axis
    """
    user_specified_origin_and_axis child of injection_child.
    """
    origin: origin = origin
    """
    origin child of injection_child.
    """
    axis: axis = axis
    """
    axis child of injection_child.
    """
    mass_criterion: mass_criterion = mass_criterion
    """
    mass_criterion child of injection_child.
    """
    physics: physics = physics
    """
    physics child of injection_child.
    """
    boundary_zones_names: boundary_zones_names = boundary_zones_names
    """
    boundary_zones_names child of injection_child.
    """
    boundary_zones: boundary_zones = boundary_zones
    """
    boundary_zones child of injection_child.
    """
    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of injection_child.
    """
    inj_mass_rate_last_tstp: inj_mass_rate_last_tstp = inj_mass_rate_last_tstp
    """
    inj_mass_rate_last_tstp child of injection_child.
    """
    inj_mass_rate_last_flow: inj_mass_rate_last_flow = inj_mass_rate_last_flow
    """
    inj_mass_rate_last_flow child of injection_child.
    """
    inj_mass_rate_prev_mass: inj_mass_rate_prev_mass = inj_mass_rate_prev_mass
    """
    inj_mass_rate_prev_mass child of injection_child.
    """
    inj_mass_rate_prev_time: inj_mass_rate_prev_time = inj_mass_rate_prev_time
    """
    inj_mass_rate_prev_time child of injection_child.
    """
    show_unsteady_rate: show_unsteady_rate = show_unsteady_rate
    """
    show_unsteady_rate child of injection_child.
    """
    old_props: old_props = old_props
    """
    old_props child of injection_child.
    """
    average_over: average_over = average_over
    """
    average_over child of injection_child.
    """
    per_injection: per_injection = per_injection
    """
    per_injection child of injection_child.
    """
    injection_list: injection_list = injection_list
    """
    injection_list child of injection_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .user_defined_function import user_defined_function
class premix_unburnt_temp(Group):
    """
    'premix_unburnt_temp' child.
    """

    fluent_name = "premix-unburnt-temp"

    child_names = \
        ['option', 'user_defined_function']

    option: option = option
    """
    option child of premix_unburnt_temp.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of premix_unburnt_temp.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class non_newtonian_modification(Boolean):
    """
    Enable/disable non-Newtonian modification for Lam-Bremhorst model.
    """

    fluent_name = "non-newtonian-modification?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .shape_factor import shape_factor
from .cunningham_factor import cunningham_factor
class particle_drag(Group):
    """
    'particle_drag' child.
    """

    fluent_name = "particle-drag"

    child_names = \
        ['option', 'shape_factor', 'cunningham_factor']

    option: option = option
    """
    option child of particle_drag.
    """
    shape_factor: shape_factor = shape_factor
    """
    shape_factor child of particle_drag.
    """
    cunningham_factor: cunningham_factor = cunningham_factor
    """
    cunningham_factor child of particle_drag.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .sample_var import sample_var
from .num_bins import num_bins
class number_of_bins(Command):
    """
    Set the number of bins to be used for a specific variable in the data reduction.
    
    Parameters
    ----------
        sample_var : str
            'sample_var' child.
        num_bins : int
            'num_bins' child.
    
    """

    fluent_name = "number-of-bins"

    argument_names = \
        ['sample_var', 'num_bins']

    sample_var: sample_var = sample_var
    """
    sample_var argument of number_of_bins.
    """
    num_bins: num_bins = num_bins
    """
    num_bins argument of number_of_bins.
    """



from ctypes import c_int, sizeof
import itertools
import os
import threading
import time
from typing import Callable, List, Optional, Tuple
import warnings
import weakref

import grpc

from ansys.fluent.core.journaling import Journal
from ansys.fluent.core.services.datamodel_se import (
    DatamodelService as DatamodelService_SE,
)
from ansys.fluent.core.services.datamodel_tui import (
    DatamodelService as DatamodelService_TUI,
)
from ansys.fluent.core.services.events import EventsService
from ansys.fluent.core.services.field_data import FieldData, FieldDataService, FieldInfo
from ansys.fluent.core.services.health_check import HealthCheckService
from ansys.fluent.core.services.monitor import MonitorsService
from ansys.fluent.core.services.scheme_eval import SchemeEval, SchemeEvalService
from ansys.fluent.core.services.settings import SettingsService
from ansys.fluent.core.streaming_services.events_streaming import EventsManager
from ansys.fluent.core.streaming_services.monitor_streaming import MonitorsManager
from ansys.fluent.core.streaming_services.transcript_streaming import Transcript


def _get_max_c_int_limit() -> int:
    """Get the maximum limit of a C int.

    Returns
    -------
    int
        The maximum limit of a C int
    """
    return 2 ** (sizeof(c_int) * 8 - 1) - 1


class MonitorThread(threading.Thread):
    """A class used for monitoring a Fluent session.

    Daemon thread which will ensure cleanup of session objects, shutdown of
    non-deamon threads etc.

    Attributes
    ----------
    cbs : List[Callable]
        Cleanup/shutdown functions
    """

    def __init__(self):
        super().__init__(daemon=True)
        self.cbs: List[Callable] = []

    def run(self) -> None:
        main_thread = threading.main_thread()
        main_thread.join()
        for cb in self.cbs:
            cb()


class _IsDataValid:
    def __init__(self, scheme_eval):
        self._scheme_eval = scheme_eval

    def __bool__(self):
        return self()

    def __call__(self):
        return self._scheme_eval.scheme_eval("(data-valid?)")


class _FluentConnection:
    """Encapsulates a Fluent connection.

    Methods
    -------
    get_current_fluent_mode()
        Gets the mode of the current instance of Fluent (meshing or
        solver).

    get_fluent_version()
        Gets and returns the fluent version.

    exit()
        Close the Fluent connection and exit Fluent.
    """

    _on_exit_cbs: List[Callable] = []
    _id_iter = itertools.count()
    _monitor_thread: Optional[MonitorThread] = None
    _writing_transcript_to_interpreter = False

    def __init__(
        self,
        start_timeout: int = 100,
        ip: str = None,
        port: int = None,
        password: str = None,
        channel: grpc.Channel = None,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
        remote_instance=None,
    ):
        """Instantiate a Session.

        Parameters
        ----------
        start_timeout: int, optional
            Maximum allowable time in seconds for connecting to the Fluent
            server. The default is ``100``.
        ip : str, optional
            IP address to connect to existing Fluent instance. Used only
            when ``channel`` is ``None``.  Defaults to ``"127.0.0.1"``
            and can also be set by the environment variable
            ``PYFLUENT_FLUENT_IP=<ip>``.
        port : int, optional
            Port to connect to existing Fluent instance. Used only
            when ``channel`` is ``None``.  Defaults value can be set by
            the environment variable ``PYFLUENT_FLUENT_PORT=<port>``.
        password : str, optional
            Password to connect to existing Fluent instance.
        channel : grpc.Channel, optional
            Grpc channel to use to connect to existing Fluent instance.
            ip and port arguments will be ignored when channel is
            specified.
        cleanup_on_exit : bool, optional
            When True, the connected Fluent session will be shut down
            when PyFluent is exited or exit() is called on the session
            instance, by default True.
        start_transcript : bool, optional
            The Fluent transcript is started in the client only when
            start_transcript is True. It can be started and stopped
            subsequently via method calls on the Session object.
        remote_instance : ansys.platform.instancemanagement.Instance
            The corresponding remote instance when Fluent is launched through
            PyPIM. This instance will be deleted when calling
            ``Session.exit()``.
        """
        self._data_valid = False
        self._channel_str = None
        if channel is not None:
            self._channel = channel
        else:
            if not ip:
                ip = os.getenv("PYFLUENT_FLUENT_IP", "127.0.0.1")
            if not port:
                port = os.getenv("PYFLUENT_FLUENT_PORT")
            self._channel_str = f"{ip}:{port}"
            if not port:
                raise ValueError(
                    "The port to connect to Fluent session is not provided."
                )
            # Same maximum message length is used in the server
            max_message_length = _get_max_c_int_limit()
            self._channel = grpc.insecure_channel(
                f"{ip}:{port}",
                options=[
                    ("grpc.max_send_message_length", max_message_length),
                    ("grpc.max_receive_message_length", max_message_length),
                ],
            )
        self._metadata: List[Tuple[str, str]] = (
            [("password", password)] if password else []
        )

        self.health_check_service = HealthCheckService(self._channel, self._metadata)

        counter = 0
        while not self.health_check_service.is_serving:
            time.sleep(1)
            counter += 1
            if counter > start_timeout:
                raise RuntimeError(
                    f"The connection to the Fluent server could not be established within the configurable {start_timeout} second time limit."
                )

        self._id = f"session-{next(_FluentConnection._id_iter)}"

        if not _FluentConnection._monitor_thread:
            _FluentConnection._monitor_thread = MonitorThread()
            _FluentConnection._monitor_thread.start()

        self.transcript = Transcript(self._channel, self._metadata)

        self._events_service = EventsService(self._channel, self._metadata)
        self.events_manager = EventsManager(self._id, self._events_service)

        self._monitors_service = MonitorsService(self._channel, self._metadata)
        self.monitors_manager = MonitorsManager(self._id, self._monitors_service)

        self.events_manager.register_callback(
            "InitializedEvent", self.monitors_manager.refresh
        )
        self.events_manager.register_callback(
            "DataReadEvent", self.monitors_manager.refresh
        )

        self.events_manager.start()
        self.datamodel_service_tui = DatamodelService_TUI(self._channel, self._metadata)
        self.datamodel_service_se = DatamodelService_SE(self._channel, self._metadata)
        self.settings_service = SettingsService(self._channel, self._metadata)

        self._scheme_eval_service = SchemeEvalService(self._channel, self._metadata)
        self.scheme_eval = SchemeEval(self._scheme_eval_service)

        self._field_data_service = FieldDataService(self._channel, self._metadata)
        self.field_info = FieldInfo(self._field_data_service)

        self.field_data = FieldData(
            self._field_data_service, self.field_info, _IsDataValid(self.scheme_eval)
        )

        self.journal = Journal(self.scheme_eval)

        self._cleanup_on_exit = cleanup_on_exit

        self.callback_id1 = None
        self.callback_id2 = None

        if start_transcript:
            self.transcript.start()

        self._remote_instance = remote_instance

        self._finalizer = weakref.finalize(
            self,
            _FluentConnection._exit,
            self._channel,
            self._cleanup_on_exit,
            self.scheme_eval,
            self.transcript,
            self.events_manager,
            self._remote_instance,
        )
        _FluentConnection._monitor_thread.cbs.append(self._finalizer)

    @property
    def id(self) -> str:
        """Return the session id."""
        return self._id

    def get_current_fluent_mode(self):
        """Gets the mode of the current instance of Fluent (meshing or
        solver)."""
        if self.scheme_eval.scheme_eval("(cx-solver-mode?)"):
            return "solver"
        else:
            return "meshing"

    def start_transcript(
        self, file_path: str = None, write_to_interpreter: bool = True
    ) -> None:
        """Start streaming of Fluent transcript."""
        warnings.warn("Use -> transcript.start()", DeprecationWarning)
        self.transcript.start(file_path, write_to_interpreter)

    def stop_transcript(self) -> None:
        """Stop streaming of Fluent transcript."""
        warnings.warn("Use -> transcript.stop()", DeprecationWarning)
        self.transcript.stop()

    def start_journal(self, file_path: str):
        """Executes tui command to start journal."""
        warnings.warn("Use -> journal.start()", DeprecationWarning)
        self.journal.start(file_path)

    def stop_journal(self):
        """Executes tui command to stop journal."""
        warnings.warn("Use -> journal.stop()", DeprecationWarning)
        self.journal.stop()

    def check_health(self) -> str:
        """Check health of Fluent connection."""
        warnings.warn("Use -> health_check_service.status()", DeprecationWarning)
        return self.health_check_service.status()

    def get_fluent_version(self):
        """Gets and returns the fluent version."""
        return self.scheme_eval.version

    def exit(self) -> None:
        """Close the Fluent connection and exit Fluent."""
        self._finalizer()

    @staticmethod
    def _exit(
        channel,
        cleanup_on_exit,
        scheme_eval,
        transcript,
        events_manager,
        remote_instance,
    ) -> None:
        if channel:
            if cleanup_on_exit:
                try:
                    scheme_eval.exec(("(exit-server)",))
                except Exception:
                    pass
            transcript.stop()
            events_manager.stop()
            channel.close()
            channel = None

        if remote_instance:
            remote_instance.delete()
